"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtCore
from PyQt6.QtGui import *
import enum


class QPalette(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qpalette.html

    **Detailed Description**

    A palette consists of three color groups: **Active** , **Disabled** , and
    **Inactive**. All widgets in Qt contain a palette and use their palette to
    draw themselves. This makes the user interface easily configurable and
    easier to keep consistent.

    If you create a new widget we strongly recommend that you use the colors in
    the palette rather than hard-coding specific colors.

    The color groups:

    * The Active group is used for the window that has keyboard focus.
      * The
    Inactive group is used for other windows.
      * The Disabled group is used for
    widgets (not windows) that are disabled for some reason.

    Both active and inactive windows can contain disabled widgets. (Disabled
    widgets are often called **inaccessible** or **grayed out**.)

    In most styles, Active and Inactive look the same.

    Colors and brushes can be set for particular roles in any of a palette's
    color groups with **setColor** () and **setBrush** (). A color group
    contains a group of colors used by widgets for drawing themselves. We
    recommend that widgets use color group roles from the palette such as
    "foreground" and "base" rather than literal colors like "red" or
    "turquoise". The color roles are enumerated and defined in the **ColorRole**
    documentation.

    We strongly recommend that you use the default palette of the current style
    (returned by **QGuiApplication::palette** ()) and modify that as necessary.
    This is done by Qt's widgets when they are drawn.

    To modify a color group you call the functions **setColor** () and
    **setBrush** (), depending on whether you want a pure color or a pixmap
    pattern.

    There are also corresponding **color** () and **brush** () getters, and a
    commonly used convenience function to get the **ColorRole**  for the current
    **ColorGroup** : **window** (), **windowText** (), **base** (), etc.

    You can copy a palette using the copy constructor and test to see if two
    palettes are **identical** using **isCopyOf** ().

    QPalette is optimized by the use of **implicit sharing** , so it is very
    efficient to pass QPalette objects as arguments.

    **Warning:** Some styles do not use the palette for all drawing, for
    instance, if they make use of native theme engines. This is the case for
    both the Windows Vista and the macOS styles.

    **See also** **QApplication::setPalette** (), **QWidget::setPalette** (),
    and **QColor** .
    """

    class ColorRole(enum.Enum):
        WindowText: QPalette = ...
        Button: QPalette = ...
        Light: QPalette = ...
        Midlight: QPalette = ...
        Dark: QPalette = ...
        Mid: QPalette = ...
        Text: QPalette = ...
        BrightText: QPalette = ...
        ButtonText: QPalette = ...
        Base: QPalette = ...
        Window: QPalette = ...
        Shadow: QPalette = ...
        Highlight: QPalette = ...
        HighlightedText: QPalette = ...
        Link: QPalette = ...
        LinkVisited: QPalette = ...
        AlternateBase: QPalette = ...
        ToolTipBase: QPalette = ...
        ToolTipText: QPalette = ...
        PlaceholderText: QPalette = ...
        NoRole: QPalette = ...
        NColorRoles: QPalette = ...

    class ColorGroup(enum.Enum):
        Active: QPalette = ...
        Disabled: QPalette = ...
        Inactive: QPalette = ...
        NColorGroups: QPalette = ...
        Current: QPalette = ...
        All: QPalette = ...
        Normal: QPalette = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#QPalette

        **QPalette::QPalette()**

        Constructs an empty palette object with no color roles set.

        When used as the palette of a **QWidget**  the colors are resolved as
        described by **QWidget::setPalette** ().

        **See also** **QApplication::setPalette** () and
        **QApplication::palette** ().
        """
        ...

    @typing.overload
    def __init__(
        self, button: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#QPalette-1

        **QPalette::QPalette(const QColor & button )**

        Constructs a palette from the **button** color. The other colors are
        automatically calculated, based on this color. `Window` will be the
        button color as well.
        """
        ...

    @typing.overload
    def __init__(self, button: QtCore.Qt.GlobalColor) -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#QPalette-2

        **QPalette::QPalette(Qt::GlobalColor button )**

        Constructs a palette from the **button** color. The other colors are
        automatically calculated, based on this color. `Window` will be the
        button color as well.
        """
        ...

    @typing.overload
    def __init__(
        self,
        button: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient],
        background: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#QPalette-3

        **QPalette::QPalette(const QColor & button , const QColor & window )**

        Constructs a palette from a **button** color and a **window**. The other
        colors are automatically calculated, based on these colors.
        """
        ...

    @typing.overload
    def __init__(
        self,
        foreground: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        button: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        light: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        dark: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        mid: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        text: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        bright_text: typing.Union[
            QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient
        ],
        base: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        background: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#QPalette-4

        **QPalette::QPalette(const QBrush & windowText , const QBrush & button ,
        const QBrush & light , const QBrush & dark , const QBrush & mid , const
        QBrush & text , const QBrush & bright_text , const QBrush & base , const
        QBrush & window )**

        Constructs a palette. You can pass either brushes, pixmaps or plain
        colors for **windowText** , **button** , **light** , **dark** , **mid**
        , **text** , **bright_text** , **base** and **window**.

        **See also** **QBrush** .
        """
        ...

    @typing.overload
    def __init__(self, palette: "QPalette") -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#QPalette-6

        **QPalette::QPalette(const QPalette & p )**

        Constructs a copy of **p**.

        This constructor is fast thanks to **implicit sharing** .
        """
        ...

    @typing.overload
    def __init__(self, variant: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#QPalette-7

        **[since 5.4] QPalette::QPalette(QPalette && other )**

        Move-constructs a QPalette instance, making it point at the same object
        that **other** was pointing to.

        After being moved from, you can only assign to or destroy **other**. Any
        other operation will result in undefined behavior.

        This function was introduced in Qt 5.4.
        """
        ...

    def swap(self, other: "QPalette") -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#swap

        **[since 5.0] void QPalette::swap(QPalette & other )**

        Swaps this palette instance with **other**. This function is very fast
        and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def cacheKey(self) -> int:
        """
        https://doc.qt.io/qt-6/qpalette.html#cacheKey

        **qint64 QPalette::cacheKey() const**

        Returns a number that identifies the contents of this **QPalette**
        object. Distinct **QPalette**  objects can have the same key if they
        refer to the same contents.

        The cacheKey() will change when the palette is altered.
        """
        ...

    def isBrushSet(self, cg: "QPalette.ColorGroup", cr: "QPalette.ColorRole") -> bool:
        """
        https://doc.qt.io/qt-6/qpalette.html#isBrushSet

        **bool QPalette::isBrushSet(QPalette::ColorGroup cg ,
        QPalette::ColorRole cr ) const**

        Returns `true` if the **ColorGroup**  **cg** and **ColorRole**  **cr**
        has been set previously on this palette; otherwise returns `false`.

        The **ColorGroup**  **cg** should be less than
        **QPalette::NColorGroups** , but you can use **QPalette::Current** . In
        this case, the previously set current color group will be used.

        The **ColorRole**  **cr** should be less than **QPalette::NColorRoles**
        .

        **See also** **setBrush** () and **currentColorGroup** ().
        """
        ...

    @typing.overload
    def setColor(
        self,
        acg: "QPalette.ColorGroup",
        acr: "QPalette.ColorRole",
        acolor: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#setColor

        **void QPalette::setColor(QPalette::ColorGroup group ,
        QPalette::ColorRole role , const QColor & color )**

        Sets the color in the specified color **group** , used for the given
        color **role** , to the specified solid **color**.

        **See also** **setBrush** (), **color** (), and **ColorRole** .
        """
        ...

    @typing.overload
    def setColor(
        self,
        acr: "QPalette.ColorRole",
        acolor: typing.Union[QColor, QtCore.Qt.GlobalColor, int, QGradient],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#setColor-1

        **void QPalette::setColor(QPalette::ColorRole role , const QColor &
        color )**

        This is an overloaded function.

        Sets the color used for the given color **role** , in all color groups,
        to the specified solid **color**.

        **See also** **brush** (), **setColor** (), and **ColorRole** .
        """
        ...

    def resolve(self, a0: "QPalette") -> "QPalette":
        """
        https://doc.qt.io/qt-6/qpalette.html#resolve

        **QPalette QPalette::resolve(const QPalette & other ) const**

        Returns a new **QPalette**  that is a union of this instance and
        **other**. Color roles set in this instance take precedence.
        """
        ...

    def isCopyOf(self, p: "QPalette") -> bool:
        """
        https://doc.qt.io/qt-6/qpalette.html#isCopyOf

        **bool QPalette::isCopyOf(const QPalette & p ) const**

        Returns `true` if this palette and **p** are copies of each other, i.e.
        one of them was created as a copy of the other and neither was
        subsequently modified; otherwise returns `false`. This is much stricter
        than equality.

        **See also** **operator=** () and **operator==** ().
        """
        ...

    def placeholderText(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#placeholderText

        **[since 5.12] const QBrush &QPalette::placeholderText() const**

        Returns the placeholder text brush of the current color group.

        **Note:** Before Qt 5.12, the placeholder text color was hard-coded as
        **QPalette::text** ().**color** () with an alpha of 128 applied. In Qt
        6, it is an independent color.

        This function was introduced in Qt 5.12.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def toolTipText(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#toolTipText

        **const QBrush &QPalette::toolTipText() const**

        Returns the tool tip text brush of the current color group. This brush
        is used by **QToolTip**  and **QWhatsThis** .

        **Note:** Tool tips use the Inactive color group of **QPalette** ,
        because tool tips are not active windows.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def toolTipBase(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#toolTipBase

        **const QBrush &QPalette::toolTipBase() const**

        Returns the tool tip base brush of the current color group. This brush
        is used by **QToolTip**  and **QWhatsThis** .

        **Note:** Tool tips use the Inactive color group of **QPalette** ,
        because tool tips are not active windows.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def linkVisited(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#linkVisited

        **const QBrush &QPalette::linkVisited() const**

        Returns the visited link text brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def link(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#link

        **const QBrush &QPalette::link() const**

        Returns the unvisited link text brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def highlightedText(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#highlightedText

        **const QBrush &QPalette::highlightedText() const**

        Returns the highlighted text brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def highlight(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#highlight

        **const QBrush &QPalette::highlight() const**

        Returns the highlight brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def shadow(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#shadow

        **const QBrush &QPalette::shadow() const**

        Returns the shadow brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def buttonText(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#buttonText

        **const QBrush &QPalette::buttonText() const**

        Returns the button text foreground brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def brightText(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#brightText

        **const QBrush &QPalette::brightText() const**

        Returns the bright text foreground brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def midlight(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#midlight

        **const QBrush &QPalette::midlight() const**

        Returns the midlight brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def window(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#window

        **const QBrush &QPalette::window() const**

        Returns the window (general background) brush of the current color
        group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def alternateBase(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#alternateBase

        **const QBrush &QPalette::alternateBase() const**

        Returns the alternate base brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def base(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#base

        **const QBrush &QPalette::base() const**

        Returns the base brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def text(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#text

        **const QBrush &QPalette::text() const**

        Returns the text foreground brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def mid(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#mid

        **const QBrush &QPalette::mid() const**

        Returns the mid brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def dark(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#dark

        **const QBrush &QPalette::dark() const**

        Returns the dark brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def light(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#light

        **const QBrush &QPalette::light() const**

        Returns the light brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def button(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#button

        **const QBrush &QPalette::button() const**

        Returns the button brush of the current color group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def windowText(self) -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#windowText

        **const QBrush &QPalette::windowText() const**

        Returns the window text (general foreground) brush of the current color
        group.

        **See also** **ColorRole**  and **brush** ().
        """
        ...

    def isEqual(self, cr1: "QPalette.ColorGroup", cr2: "QPalette.ColorGroup") -> bool:
        """
        https://doc.qt.io/qt-6/qpalette.html#isEqual

        **bool QPalette::isEqual(QPalette::ColorGroup cg1 , QPalette::ColorGroup
        cg2 ) const**

        Returns `true` (usually quickly) if color group **cg1** is equal to
        **cg2** ; otherwise returns `false`.
        """
        ...

    def setColorGroup(
        self,
        cr: "QPalette.ColorGroup",
        foreground: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        button: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        light: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        dark: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        mid: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        text: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        bright_text: typing.Union[
            QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient
        ],
        base: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
        background: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#setColorGroup

        **void QPalette::setColorGroup(QPalette::ColorGroup cg , const QBrush &
        windowText , const QBrush & button , const QBrush & light , const QBrush
        & dark , const QBrush & mid , const QBrush & text , const QBrush &
        bright_text , const QBrush & base , const QBrush & window )**

        Sets a the group at **cg**. You can pass either brushes, pixmaps or
        plain colors for **windowText** , **button** , **light** , **dark** ,
        **mid** , **text** , **bright_text** , **base** and **window**.

        **See also** **QBrush** .
        """
        ...

    @typing.overload
    def setBrush(
        self,
        cg: "QPalette.ColorGroup",
        cr: "QPalette.ColorRole",
        brush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#setBrush

        **void QPalette::setBrush(QPalette::ColorRole role , const QBrush &
        brush )**

        Sets the brush for the given color **role** to the specified **brush**
        for all groups in the palette.

        **See also** **brush** (), **setColor** (), and **ColorRole** .
        """
        ...

    @typing.overload
    def setBrush(
        self,
        acr: "QPalette.ColorRole",
        abrush: typing.Union[QBrush, QColor, QtCore.Qt.GlobalColor, int, QGradient],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#setBrush-1

        **void QPalette::setBrush(QPalette::ColorGroup group ,
        QPalette::ColorRole role , const QBrush & brush )**

        This is an overloaded function.

        Sets the brush in the specified color **group** , used for the given
        color **role** , to **brush**.

        **See also** **brush** (), **setColor** (), and **ColorRole** .
        """
        ...

    @typing.overload
    def brush(self, cg: "QPalette.ColorGroup", cr: "QPalette.ColorRole") -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#brush

        **const QBrush &QPalette::brush(QPalette::ColorGroup group ,
        QPalette::ColorRole role ) const**

        Returns the brush in the specified color **group** , used for the given
        color **role**.

        **See also** **color** (), **setBrush** (), and **ColorRole** .
        """
        ...

    @typing.overload
    def brush(self, cr: "QPalette.ColorRole") -> QBrush:
        """
        https://doc.qt.io/qt-6/qpalette.html#brush-1

        **const QBrush &QPalette::brush(QPalette::ColorRole role ) const**

        This is an overloaded function.

        Returns the brush that has been set for the given color **role** in the
        current **ColorGroup** .

        **See also** **color** (), **setBrush** (), and **ColorRole** .
        """
        ...

    @typing.overload
    def color(self, cg: "QPalette.ColorGroup", cr: "QPalette.ColorRole") -> QColor:
        """
        https://doc.qt.io/qt-6/qpalette.html#color

        **const QColor &QPalette::color(QPalette::ColorGroup group ,
        QPalette::ColorRole role ) const**

        Returns the color in the specified color **group** , used for the given
        color **role**.

        **See also** **brush** (), **setColor** (), and **ColorRole** .
        """
        ...

    @typing.overload
    def color(self, cr: "QPalette.ColorRole") -> QColor:
        """
        https://doc.qt.io/qt-6/qpalette.html#color-1

        **const QColor &QPalette::color(QPalette::ColorRole role ) const**

        This is an overloaded function.

        Returns the color that has been set for the given color **role** in the
        current **ColorGroup** .

        **See also** **brush** () and **ColorRole** .
        """
        ...

    def setCurrentColorGroup(self, cg: "QPalette.ColorGroup") -> None:
        """
        https://doc.qt.io/qt-6/qpalette.html#setCurrentColorGroup

        **void QPalette::setCurrentColorGroup(QPalette::ColorGroup cg )**

        Set the palette's current color group to **cg**.

        **See also** **currentColorGroup** ().
        """
        ...

    def currentColorGroup(self) -> "QPalette.ColorGroup":
        """
        https://doc.qt.io/qt-6/qpalette.html#currentColorGroup

        **QPalette::ColorGroup QPalette::currentColorGroup() const**

        Returns the palette's current color group.

        **See also** **setCurrentColorGroup** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
from ._functions import PYQT_SIGNAL as PYQT_SIGNAL
from ._functions import PYQT_SLOT as PYQT_SLOT
from ._QRemoteObjectSourceLocationInfo import (
    QRemoteObjectSourceLocationInfo as QRemoteObjectSourceLocationInfo,
)
from ._QtRemoteObjects import QtRemoteObjects as QtRemoteObjects
from ._QAbstractItemModelReplica import (
    QAbstractItemModelReplica as QAbstractItemModelReplica,
)
from ._QRemoteObjectReplica import QRemoteObjectReplica as QRemoteObjectReplica
from ._QRemoteObjectDynamicReplica import (
    QRemoteObjectDynamicReplica as QRemoteObjectDynamicReplica,
)
from ._QRemoteObjectAbstractPersistedStore import (
    QRemoteObjectAbstractPersistedStore as QRemoteObjectAbstractPersistedStore,
)
from ._QRemoteObjectNode import QRemoteObjectNode as QRemoteObjectNode
from ._QRemoteObjectHostBase import QRemoteObjectHostBase as QRemoteObjectHostBase
from ._QRemoteObjectHost import QRemoteObjectHost as QRemoteObjectHost
from ._QRemoteObjectRegistryHost import (
    QRemoteObjectRegistryHost as QRemoteObjectRegistryHost,
)
from ._QRemoteObjectRegistry import QRemoteObjectRegistry as QRemoteObjectRegistry



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtCore


class QDesignerMemberSheetExtension(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qdesignermembersheetextension.html

    **Detailed Description**

    QDesignerMemberSheetExtension is a collection of functions that is typically
    used to query a widget's member functions, and to manipulate the member
    functions' appearance in **Qt Designer** 's signals and slots editing mode.
    For example:

    QDesignerMemberSheetExtension *memberSheet  = 0;
        **QExtensionManager**
    manager = formEditor->extensionManager();

        memberSheet =
    qt_extension<QDesignerMemberSheetExtension*>(manager, widget);
        int index
    = memberSheet->indexOf(setEchoMode);
        memberSheet->setVisible(index,
    false);

        delete memberSheet;

    When implementing a custom widget plugin, a pointer to **Qt Designer** 's
    current **QDesignerFormEditorInterface**  object (`formEditor` in the
    example above) is provided by the
    **QDesignerCustomWidgetInterface::initialize** () function's parameter.

    The member sheet (and any other extension), can be retrieved by querying
    **Qt Designer** 's extension manager using the **qt_extension** () function.
    When you want to release the extension, you only need to delete the pointer.

    All widgets have a default member sheet used in **Qt Designer** 's signals
    and slots editing mode with the widget's member functions. But
    QDesignerMemberSheetExtension also provides an interface for creating custom
    member sheet extensions.

    **Warning:** **Qt Designer** uses the QDesignerMemberSheetExtension to
    facilitate the signal and slot editing mode. Whenever a connection between
    two widgets is requested, **Qt Designer** will query for the widgets' member
    sheet extensions. If a widget has an implemented member sheet extension,
    this extension will override the default member sheet.

    To create a member sheet extension, your extension class must inherit from
    both **QObject**  and QDesignerMemberSheetExtension. Then, since we are
    implementing an interface, we must ensure that it's made known to the meta
    object system using the **Q_INTERFACES** () macro:

    class MyMemberSheetExtension : public **QObject** ,
                public
    QDesignerMemberSheetExtension
        {
            Q_OBJECT
    Q_INTERFACES(QDesignerMemberSheetExtension)

        public:
            ...
    }

    This enables **Qt Designer** to use **qobject_cast** () to query for
    supported interfaces using nothing but a **QObject**  pointer.

    In **Qt Designer** the extensions are not created until they are required.
    For that reason, when implementing a member sheet extension, you must also
    create a **QExtensionFactory** , i.e a class that is able to make an
    instance of your extension, and register it using **Qt Designer** 's
    **extension manager** .

    When a widget's member sheet extension is required, **Qt Designer** 's
    **extension manager**  will run through all its registered factories calling
    **QExtensionFactory::createExtension** () for each until the first one that
    is able to create a member sheet extension for that widget, is found. This
    factory will then make an instance of the extension. If no such factory is
    found, **Qt Designer** will use the default member sheet.

    There are four available types of extensions in **Qt Designer** :
    **QDesignerContainerExtension** , QDesignerMemberSheetExtension,
    **QDesignerPropertySheetExtension**  and **QDesignerTaskMenuExtension** .
    **Qt Designer** 's behavior is the same whether the requested extension is
    associated with a multi page container, a member sheet, a property sheet or
    a task menu.

    The **QExtensionFactory**  class provides a standard extension factory, and
    can also be used as an interface for custom extension factories. You can
    either create a new **QExtensionFactory**  and reimplement the
    **QExtensionFactory::createExtension** () function. For example:

    **QObject**  *ANewExtensionFactory::createExtension(**QObject**  *object,
    const **QString**  &iid, **QObject**  *parent) const
        {
            if (iid
    != Q_TYPEID(QDesignerMemberSheetExtension))
                return 0;
    if (MyCustomWidget *widget = qobject_cast<MyCustomWidget*>
    (object))
                return new MyMemberSheetExtension(widget, parent);
    return 0;
        }

    Or you can use an existing factory, expanding the
    **QExtensionFactory::createExtension** () function to make the factory able
    to create a member sheet extension as well. For example:

    **QObject**  *AGeneralExtensionFactory::createExtension(**QObject**
    *object,
                const **QString**  &iid, **QObject**  *parent) const
    {
            MyCustomWidget *widget = qobject_cast<MyCustomWidget*>(object);
    if (widget && (iid == Q_TYPEID(**QDesignerTaskMenuExtension** ))) {
    return new MyTaskMenuExtension(widget, parent);

            } else if
    (widget && (iid == Q_TYPEID(QDesignerMemberSheetExtension))) {
    return new MyMemberSheetExtension(widget, parent);

            } else {
    return 0;
            }
        }

    For a complete example using an extension class, see **Task Menu Extension
    example** . The example shows how to create a custom widget plugin for Qt
    Designer, and how to to use the **QDesignerTaskMenuExtension**  class to add
    custom items to **Qt Designer** 's task menu.

    **See also** **QExtensionFactory** , **QExtensionManager** , and **Creating
    Custom Widget Extensions** .
    """

    def __init__(self) -> None:
        ...

    def parameterNames(self, index: int) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#parameterNames

        **[pure virtual] QList<QByteArray>
        QDesignerMemberSheetExtension::parameterNames(int index ) const**

        Returns the parameter names of the member function with the given
        **index** , as a **QByteArray**  list.

        **See also** **indexOf** () and **parameterTypes** ().
        """
        ...

    def parameterTypes(self, index: int) -> typing.List[QtCore.QByteArray]:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#parameterTypes

        **[pure virtual] QList<QByteArray>
        QDesignerMemberSheetExtension::parameterTypes(int index ) const**

        Returns the parameter types of the member function with the given
        **index** , as a **QByteArray**  list.

        **See also** **indexOf** () and **parameterNames** ().
        """
        ...

    def signature(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#signature

        **[pure virtual] QString QDesignerMemberSheetExtension::signature(int
        index ) const**

        Returns the signature of the member function with the given **index**.

        **See also** **indexOf** ().
        """
        ...

    def declaredInClass(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#declaredInClas
        s

        **[pure virtual] QString
        QDesignerMemberSheetExtension::declaredInClass(int index ) const**

        Returns the name of the class in which the member function with the
        given **index** is declared.

        **See also** **indexOf** ().
        """
        ...

    def inheritedFromWidget(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#inheritedFromW
        idget

        **[pure virtual] bool
        QDesignerMemberSheetExtension::inheritedFromWidget(int index ) const**

        Returns true if the member function with the given **index** is
        inherited from **QWidget** , otherwise false.

        **See also** **indexOf** ().
        """
        ...

    def isSlot(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#isSlot

        **[pure virtual] bool QDesignerMemberSheetExtension::isSlot(int index )
        const**

        Returns true if the member function with the given **index** is a slot,
        otherwise false.

        **See also** **indexOf** ().
        """
        ...

    def isSignal(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#isSignal

        **[pure virtual] bool QDesignerMemberSheetExtension::isSignal(int index
        ) const**

        Returns true if the member function with the given **index** is a
        signal, otherwise false.

        **See also** **indexOf** ().
        """
        ...

    def setVisible(self, index: int, b: bool) -> None:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#setVisible

        **[pure virtual] void QDesignerMemberSheetExtension::setVisible(int
        index , bool visible )**

        If **visible** is true, the member function with the given **index** is
        visible in **Qt Designer** 's signals and slots editing mode; otherwise
        the member function is hidden.

        **See also** **indexOf** () and **isVisible** ().
        """
        ...

    def isVisible(self, index: int) -> bool:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#isVisible

        **[pure virtual] bool QDesignerMemberSheetExtension::isVisible(int index
        ) const**

        Returns true if the member function with the given **index** is visible
        in **Qt Designer** 's signal and slot editor, otherwise false.

        **See also** **indexOf** () and **setVisible** ().
        """
        ...

    def setMemberGroup(self, index: int, group: str) -> None:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#setMemberGroup

        **[pure virtual] void QDesignerMemberSheetExtension::setMemberGroup(int
        index , const QString & group )**

        Sets the member group of the member function with the given **index** ,
        to **group**.

        **See also** **indexOf** () and **memberGroup** ().
        """
        ...

    def memberGroup(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#memberGroup

        **[pure virtual] QString QDesignerMemberSheetExtension::memberGroup(int
        index ) const**

        Returns the name of the member group specified for the function with the
        given **index**.

        **See also** **indexOf** () and **setMemberGroup** ().
        """
        ...

    def memberName(self, index: int) -> str:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#memberName

        **[pure virtual] QString QDesignerMemberSheetExtension::memberName(int
        index ) const**

        Returns the name of the member function with the given **index**.

        **See also** **indexOf** ().
        """
        ...

    def indexOf(self, name: str) -> int:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#indexOf

        **[pure virtual] int QDesignerMemberSheetExtension::indexOf(const
        QString & name ) const**

        Returns the index of the member function specified by the given
        **name**.

        **See also** **memberName** ().
        """
        ...

    def __len__(self) -> int:
        ...

    def count(self) -> int:
        """
        https://doc.qt.io/qt-6/qdesignermembersheetextension.html#count

        **[pure virtual] int QDesignerMemberSheetExtension::count() const**

        Returns the extension's number of member functions.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtCore import *


class QRectF(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qrectf.html

    **Detailed Description**

    A rectangle is normally expressed as a top-left corner and a size. The size
    (width and height) of a QRectF is always equivalent to the mathematical
    rectangle that forms the basis for its rendering.

    A QRectF can be constructed with a set of left, top, width and height
    coordinates, or from a **QPointF**  and a **QSizeF** . The following code
    creates two identical rectangles.

    **QRectF**  r1(100.0, 200.1, 11.2, 16.3);
        **QRectF**  r2(**QPointF**
    (100.0, 200.1), **QSizeF** (11.2, 16.3));

    There is also a third constructor creating a QRectF from a **QRect** , and a
    corresponding **toRect** () function that returns a **QRect**  object based
    on the values of this rectangle (note that the coordinates in the returned
    rectangle are rounded to the nearest integer).

    The QRectF class provides a collection of functions that return the various
    rectangle coordinates, and enable manipulation of these. QRectF also
    provides functions to move the rectangle relative to the various
    coordinates. In addition there is a **moveTo** () function that moves the
    rectangle, leaving its top left corner at the given coordinates.
    Alternatively, the **translate** () function moves the rectangle the given
    offset relative to the current position, and the **translated** () function
    returns a translated copy of this rectangle.

    The **size** () function returns the rectangle's dimensions as a **QSizeF**
    . The dimensions can also be retrieved separately using the **width** () and
    **height** () functions. To manipulate the dimensions use the **setSize**
    (), **setWidth** () or **setHeight** () functions. Alternatively, the size
    can be changed by applying either of the functions setting the rectangle
    coordinates, for example, **setBottom** () or **setRight** ().

    The **contains** () function tells whether a given point is inside the
    rectangle or not, and the **intersects** () function returns `true` if this
    rectangle intersects with a given rectangle (otherwise false). The QRectF
    class also provides the **intersected** () function which returns the
    intersection rectangle, and the **united** () function which returns the
    rectangle that encloses the given rectangle and this:

    ![](images/qrect-intersect.png)![](images/qrect-unite.png)
    **intersected**
    ()**united** ()

    The **isEmpty** () function returns `true` if the rectangle's width or
    height is less than, or equal to, 0. Note that an empty rectangle is not
    valid: The **isValid** () function returns `true` if both width and height
    is larger than 0. A null rectangle (**isNull** () == true) on the other
    hand, has both width and height set to 0.

    Note that due to the way **QRect**  and QRectF are defined, an empty QRectF
    is defined in essentially the same way as **QRect** .

    Finally, QRectF objects can be streamed as well as compared.

    **Rendering**

    When using an **anti-aliased**  painter, the boundary line of a QRectF will
    be rendered symmetrically on both sides of the mathematical rectangle's
    boundary line. But when using an aliased painter (the default) other rules
    apply.

    Then, when rendering with a one pixel wide pen the QRectF's boundary line
    will be rendered to the right and below the mathematical rectangle's
    boundary line.

    When rendering with a two pixels wide pen the boundary line will be split in
    the middle by the mathematical rectangle. This will be the case whenever the
    pen is set to an even number of pixels, while rendering with a pen with an
    odd number of pixels, the spare pixel will be rendered to the right and
    below the mathematical rectangle as in the one pixel case.

    ![](images/qrect-diagram-zero.png)![](images/qrectf-diagram-one.png)
    Logical representationOne pixel wide pen
    ![](images/qrectf-diagram-
    two.png)![](images/qrectf-diagram-three.png)
    Two pixel wide penThree pixel
    wide pen

    **Coordinates**

    The QRectF class provides a collection of functions that return the various
    rectangle coordinates, and enable manipulation of these. QRectF also
    provides functions to move the rectangle relative to the various
    coordinates.

    For example: the **bottom** (), **setBottom** () and **moveBottom** ()
    functions: **bottom** () returns the y-coordinate of the rectangle's bottom
    edge, **setBottom** () sets the bottom edge of the rectangle to the given y
    coordinate (it may change the height, but will never change the rectangle's
    top edge) and **moveBottom** () moves the entire rectangle vertically,
    leaving the rectangle's bottom edge at the given y coordinate and its size
    unchanged.

    ![](images/qrectf-coordinates.png)

    It is also possible to add offsets to this rectangle's coordinates using the
    **adjust** () function, as well as retrieve a new rectangle based on
    adjustments of the original one using the **adjusted** () function. If
    either of the width and height is negative, use the **normalized** ()
    function to retrieve a rectangle where the corners are swapped.

    In addition, QRectF provides the **getCoords** () function which extracts
    the position of the rectangle's top-left and bottom-right corner, and the
    **getRect** () function which extracts the rectangle's top-left corner,
    width and height. Use the **setCoords** () and **setRect** () function to
    manipulate the rectangle's coordinates and dimensions in one go.

    **See also** **QRect**  and **QRegion** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#QRectF

        **QRectF::QRectF()**

        Constructs a null rectangle.

        **See also** **isNull** ().
        """
        ...

    @typing.overload
    def __init__(self, atopLeft: QPointF, asize: "QSizeF") -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#QRectF-1

        **QRectF::QRectF(const QPointF & topLeft , const QSizeF & size )**

        Constructs a rectangle with the given **topLeft** corner and the given
        **size**.

        **See also** **setTopLeft** () and **setSize** ().
        """
        ...

    @typing.overload
    def __init__(self, atopLeft: QPointF, abottomRight: QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#QRectF-2

        **QRectF::QRectF(const QPointF & topLeft , const QPointF & bottomRight
        )**

        Constructs a rectangle with the given **topLeft** and **bottomRight**
        corners.

        **See also** **setTopLeft** () and **setBottomRight** ().
        """
        ...

    @typing.overload
    def __init__(
        self, aleft: float, atop: float, awidth: float, aheight: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#QRectF-3

        **QRectF::QRectF(qreal x , qreal y , qreal width , qreal height )**

        Constructs a rectangle with ( **x** , **y** ) as its top-left corner and
        the given **width** and **height**. All parameters must be finite.

        **See also** **setRect** ().
        """
        ...

    @typing.overload
    def __init__(self, r: QRect) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#QRectF-4

        **QRectF::QRectF(const QRect & rectangle )**

        Constructs a QRectF rectangle from the given **QRect**  **rectangle**.

        **See also** **toRect** ().
        """
        ...

    @typing.overload
    def __init__(self, a0: "QRectF") -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#QRectF

        **QRectF::QRectF()**

        Constructs a null rectangle.

        **See also** **isNull** ().
        """
        ...

    def transposed(self) -> "QRectF":
        """
        https://doc.qt.io/qt-6/qrectf.html#transposed

        **[since 5.7] QRectF QRectF::transposed() const**

        Returns a copy of the rectangle that has its width and height exchanged:

        **QRectF**  r = {1.5, 5.1, 4.2, 2.4};
            r = r.transposed(); // r ==
        {1.5, 5.1, 2.4, 4.2}

        This function was introduced in Qt 5.7.

        **See also** **QSizeF::transposed** ().
        """
        ...

    def marginsRemoved(self, margins: QMarginsF) -> "QRectF":
        """
        https://doc.qt.io/qt-6/qrectf.html#marginsRemoved

        **[since 5.3] QRectF QRectF::marginsRemoved(const QMarginsF & margins )
        const**

        Removes the **margins** from the rectangle, shrinking it.

        This function was introduced in Qt 5.3.

        **See also** **marginsAdded** (), **operator+=** (), and **operator-=**
        ().
        """
        ...

    def marginsAdded(self, margins: QMarginsF) -> "QRectF":
        """
        https://doc.qt.io/qt-6/qrectf.html#marginsAdded

        **[since 5.3] QRectF QRectF::marginsAdded(const QMarginsF & margins )
        const**

        Returns a rectangle grown by the **margins**.

        This function was introduced in Qt 5.3.

        **See also** **operator+=** (), **marginsRemoved** (), and
        **operator-=** ().
        """
        ...

    def toRect(self) -> QRect:
        """
        https://doc.qt.io/qt-6/qrectf.html#toRect

        **QRect QRectF::toRect() const**

        Returns a **QRect**  based on the values of this rectangle. Note that
        the coordinates in the returned rectangle are rounded to the nearest
        integer.

        **See also** **QRectF** () and **toAlignedRect** ().
        """
        ...

    def toAlignedRect(self) -> QRect:
        """
        https://doc.qt.io/qt-6/qrectf.html#toAlignedRect

        **QRect QRectF::toAlignedRect() const**

        Returns a **QRect**  based on the values of this rectangle that is the
        smallest possible integer rectangle that completely contains this
        rectangle.

        **See also** **toRect** ().
        """
        ...

    def united(self, r: "QRectF") -> "QRectF":
        """
        https://doc.qt.io/qt-6/qrectf.html#united

        **QRectF QRectF::united(const QRectF & rectangle ) const**

        Returns the bounding rectangle of this rectangle and the given
        **rectangle**.

        ![](images/qrect-unite.png)

        **See also** **intersected** ().
        """
        ...

    def intersected(self, r: "QRectF") -> "QRectF":
        """
        https://doc.qt.io/qt-6/qrectf.html#intersected

        **QRectF QRectF::intersected(const QRectF & rectangle ) const**

        Returns the intersection of this rectangle and the given **rectangle**.
        Note that `r.intersected(s)` is equivalent to `r & s`.

        ![](images/qrect-intersect.png)

        **See also** **intersects** (), **united** (), and **operator&=** ().
        """
        ...

    def setSize(self, s: "QSizeF") -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setSize

        **void QRectF::setSize(const QSizeF & size )**

        Sets the size of the rectangle to the given finite **size**. The top-
        left corner is not moved.

        **See also** **size** (), **setWidth** (), and **setHeight** ().
        """
        ...

    def setHeight(self, ah: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setHeight

        **void QRectF::setHeight(qreal height )**

        Sets the height of the rectangle to the given finite **height**. The
        bottom edge is changed, but not the top one.

        **See also** **height** () and **setSize** ().
        """
        ...

    def setWidth(self, aw: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setWidth

        **void QRectF::setWidth(qreal width )**

        Sets the width of the rectangle to the given finite **width**. The right
        edge is changed, but not the left one.

        **See also** **width** () and **setSize** ().
        """
        ...

    def adjusted(self, xp1: float, yp1: float, xp2: float, yp2: float) -> "QRectF":
        """
        https://doc.qt.io/qt-6/qrectf.html#adjusted

        **QRectF QRectF::adjusted(qreal dx1 , qreal dy1 , qreal dx2 , qreal dy2
        ) const**

        Returns a new rectangle with **dx1** , **dy1** , **dx2** and **dy2**
        added respectively to the existing coordinates of this rectangle. All
        parameters must be finite.

        **See also** **adjust** ().
        """
        ...

    def adjust(self, xp1: float, yp1: float, xp2: float, yp2: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#adjust

        **void QRectF::adjust(qreal dx1 , qreal dy1 , qreal dx2 , qreal dy2 )**

        Adds **dx1** , **dy1** , **dx2** and **dy2** respectively to the
        existing coordinates of the rectangle. All parameters must be finite.

        **See also** **adjusted** () and **setRect** ().
        """
        ...

    def setCoords(self, xp1: float, yp1: float, xp2: float, yp2: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setCoords

        **void QRectF::setCoords(qreal x1 , qreal y1 , qreal x2 , qreal y2 )**

        Sets the coordinates of the rectangle's top-left corner to ( **x1** ,
        **y1** ), and the coordinates of its bottom-right corner to ( **x2** ,
        **y2** ). All parameters must be finite.

        **See also** **getCoords** () and **setRect** ().
        """
        ...

    def getCoords(self) -> typing.Tuple[float, float, float, float]:
        """
        https://doc.qt.io/qt-6/qrectf.html#getCoords

        **void QRectF::getCoords(qreal * x1 , qreal * y1 , qreal * x2 , qreal *
        y2 ) const**

        Extracts the position of the rectangle's top-left corner to * **x1** and
        * **y1** , and the position of the bottom-right corner to * **x2** and *
        **y2**.

        **See also** **setCoords** () and **getRect** ().
        """
        ...

    def setRect(self, ax: float, ay: float, aaw: float, aah: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setRect

        **void QRectF::setRect(qreal x , qreal y , qreal width , qreal height
        )**

        Sets the coordinates of the rectangle's top-left corner to ( **x** ,
        **y** ), and its size to the given **width** and **height**. All
        parameters must be finite.

        **See also** **getRect** () and **setCoords** ().
        """
        ...

    def getRect(self) -> typing.Tuple[float, float, float, float]:
        """
        https://doc.qt.io/qt-6/qrectf.html#getRect

        **void QRectF::getRect(qreal * x , qreal * y , qreal * width , qreal *
        height ) const**

        Extracts the position of the rectangle's top-left corner to * **x** and
        * **y** , and its dimensions to * **width** and * **height**.

        **See also** **setRect** () and **getCoords** ().
        """
        ...

    @typing.overload
    def translated(self, dx: float, dy: float) -> "QRectF":
        """
        https://doc.qt.io/qt-6/qrectf.html#translated

        **QRectF QRectF::translated(qreal dx , qreal dy ) const**

        Returns a copy of the rectangle that is translated **dx** along the x
        axis and **dy** along the y axis, relative to the current position.
        Positive values move the rectangle to the right and down. Both
        parameters must be finite.

        **See also** **translate** ().
        """
        ...

    @typing.overload
    def translated(self, p: QPointF) -> "QRectF":
        """
        https://doc.qt.io/qt-6/qrectf.html#translated-1

        **QRectF QRectF::translated(const QPointF & offset ) const**

        This is an overloaded function.

        Returns a copy of the rectangle that is translated **offset**.**x** ()
        along the x axis and **offset**.**y** () along the y axis, relative to
        the current position.
        """
        ...

    @typing.overload
    def moveTo(self, ax: float, ay: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#moveTo

        **void QRectF::moveTo(qreal x , qreal y )**

        Moves the rectangle, leaving the top-left corner at the given position (
        **x** , **y** ). The rectangle's size is unchanged. Both parameters must
        be finite.

        **See also** **translate** () and **moveTopLeft** ().
        """
        ...

    @typing.overload
    def moveTo(self, p: QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#moveTo-1

        **void QRectF::moveTo(const QPointF & position )**

        This is an overloaded function.

        Moves the rectangle, leaving the top-left corner at the given
        **position**.
        """
        ...

    @typing.overload
    def translate(self, dx: float, dy: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#translate

        **void QRectF::translate(qreal dx , qreal dy )**

        Moves the rectangle **dx** along the x-axis and **dy** along the y-axis,
        relative to the current position. Positive values move the rectangle to
        the right and downwards. Both parameters must be finite.

        **See also** **moveTopLeft** (), **moveTo** (), and **translated** ().
        """
        ...

    @typing.overload
    def translate(self, p: QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#translate-1

        **void QRectF::translate(const QPointF & offset )**

        This is an overloaded function.

        Moves the rectangle **offset**.**x** () along the x axis and
        **offset**.**y** () along the y axis, relative to the current position.
        """
        ...

    def size(self) -> "QSizeF":
        """
        https://doc.qt.io/qt-6/qrectf.html#size

        **QSizeF QRectF::size() const**

        Returns the size of the rectangle.

        **See also** **setSize** (), **width** (), and **height** ().
        """
        ...

    def height(self) -> float:
        """
        https://doc.qt.io/qt-6/qrectf.html#height

        **qreal QRectF::height() const**

        Returns the height of the rectangle.

        **See also** **setHeight** (), **width** (), and **size** ().
        """
        ...

    def width(self) -> float:
        """
        https://doc.qt.io/qt-6/qrectf.html#width

        **qreal QRectF::width() const**

        Returns the width of the rectangle.

        **See also** **setWidth** (), **height** (), and **size** ().
        """
        ...

    def moveCenter(self, p: QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#moveCenter

        **void QRectF::moveCenter(const QPointF & position )**

        Moves the rectangle, leaving the center point at the given **position**.
        The rectangle's size is unchanged.

        **See also** **center** ().
        """
        ...

    def moveBottomRight(self, p: QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#moveBottomRight

        **void QRectF::moveBottomRight(const QPointF & position )**

        Moves the rectangle, leaving the bottom-right corner at the given
        **position**. The rectangle's size is unchanged.

        **See also** **setBottomRight** (), **moveBottom** (), and **moveRight**
        ().
        """
        ...

    def moveBottomLeft(self, p: QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#moveBottomLeft

        **void QRectF::moveBottomLeft(const QPointF & position )**

        Moves the rectangle, leaving the bottom-left corner at the given
        **position**. The rectangle's size is unchanged.

        **See also** **setBottomLeft** (), **moveBottom** (), and **moveLeft**
        ().
        """
        ...

    def moveTopRight(self, p: QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#moveTopRight

        **void QRectF::moveTopRight(const QPointF & position )**

        Moves the rectangle, leaving the top-right corner at the given
        **position**. The rectangle's size is unchanged.

        **See also** **setTopRight** (), **moveTop** (), and **moveRight** ().
        """
        ...

    def moveTopLeft(self, p: QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#moveTopLeft

        **void QRectF::moveTopLeft(const QPointF & position )**

        Moves the rectangle, leaving the top-left corner at the given
        **position**. The rectangle's size is unchanged.

        **See also** **setTopLeft** (), **moveTop** (), and **moveLeft** ().
        """
        ...

    def moveBottom(self, pos: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#moveBottom

        **void QRectF::moveBottom(qreal y )**

        Moves the rectangle vertically, leaving the rectangle's bottom edge at
        the given finite **y** coordinate. The rectangle's size is unchanged.

        **See also** **bottom** (), **setBottom** (), and **moveTop** ().
        """
        ...

    def moveRight(self, pos: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#moveRight

        **void QRectF::moveRight(qreal x )**

        Moves the rectangle horizontally, leaving the rectangle's right edge at
        the given finite **x** coordinate. The rectangle's size is unchanged.

        **See also** **right** (), **setRight** (), and **moveLeft** ().
        """
        ...

    def moveTop(self, pos: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#moveTop

        **void QRectF::moveTop(qreal y )**

        Moves the rectangle vertically, leaving the rectangle's top line at the
        given finite **y** coordinate. The rectangle's size is unchanged.

        **See also** **top** (), **setTop** (), and **moveBottom** ().
        """
        ...

    def moveLeft(self, pos: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#moveLeft

        **void QRectF::moveLeft(qreal x )**

        Moves the rectangle horizontally, leaving the rectangle's left edge at
        the given finite **x** coordinate. The rectangle's size is unchanged.

        **See also** **left** (), **setLeft** (), and **moveRight** ().
        """
        ...

    def center(self) -> QPointF:
        """
        https://doc.qt.io/qt-6/qrectf.html#center

        **QPointF QRectF::center() const**

        Returns the center point of the rectangle.

        **See also** **moveCenter** ().
        """
        ...

    def setBottomRight(self, p: QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setBottomRight

        **void QRectF::setBottomRight(const QPointF & position )**

        Set the bottom-right corner of the rectangle to the given **position**.
        May change the size, but will never change the top-left corner of the
        rectangle.

        **See also** **bottomRight** () and **moveBottomRight** ().
        """
        ...

    def setBottomLeft(self, p: QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setBottomLeft

        **void QRectF::setBottomLeft(const QPointF & position )**

        Set the bottom-left corner of the rectangle to the given **position**.
        May change the size, but will never change the top-right corner of the
        rectangle.

        **See also** **bottomLeft** () and **moveBottomLeft** ().
        """
        ...

    def setTopRight(self, p: QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setTopRight

        **void QRectF::setTopRight(const QPointF & position )**

        Set the top-right corner of the rectangle to the given **position**. May
        change the size, but will never change the bottom-left corner of the
        rectangle.

        **See also** **topRight** () and **moveTopRight** ().
        """
        ...

    def setTopLeft(self, p: QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setTopLeft

        **void QRectF::setTopLeft(const QPointF & position )**

        Set the top-left corner of the rectangle to the given **position**. May
        change the size, but will never change the bottom-right corner of the
        rectangle.

        **See also** **topLeft** () and **moveTopLeft** ().
        """
        ...

    def setBottom(self, pos: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setBottom

        **void QRectF::setBottom(qreal y )**

        Sets the bottom edge of the rectangle to the given finite **y**
        coordinate. May change the height, but will never change the top edge of
        the rectangle.

        **See also** **bottom** () and **moveBottom** ().
        """
        ...

    def setTop(self, pos: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setTop

        **void QRectF::setTop(qreal y )**

        Sets the top edge of the rectangle to the given finite **y** coordinate.
        May change the height, but will never change the bottom edge of the
        rectangle.

        Equivalent to **setY** ().

        **See also** **top** () and **moveTop** ().
        """
        ...

    def setRight(self, pos: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setRight

        **void QRectF::setRight(qreal x )**

        Sets the right edge of the rectangle to the given finite **x**
        coordinate. May change the width, but will never change the left edge of
        the rectangle.

        **See also** **right** () and **moveRight** ().
        """
        ...

    def setLeft(self, pos: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setLeft

        **void QRectF::setLeft(qreal x )**

        Sets the left edge of the rectangle to the given finite **x**
        coordinate. May change the width, but will never change the right edge
        of the rectangle.

        Equivalent to **setX** ().

        **See also** **left** () and **moveLeft** ().
        """
        ...

    def y(self) -> float:
        """
        https://doc.qt.io/qt-6/qrectf.html#y

        **qreal QRectF::y() const**

        Returns the y-coordinate of the rectangle's top edge. Equivalent to
        **top** ().

        **See also** **setY** (), **x** (), and **topLeft** ().
        """
        ...

    def x(self) -> float:
        """
        https://doc.qt.io/qt-6/qrectf.html#x

        **qreal QRectF::x() const**

        Returns the x-coordinate of the rectangle's left edge. Equivalent to
        **left** ().

        **See also** **setX** (), **y** (), and **topLeft** ().
        """
        ...

    def __bool__(self) -> int:
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qrectf.html#isValid

        **bool QRectF::isValid() const**

        Returns `true` if the rectangle is valid, otherwise returns `false`.

        A valid rectangle has a **width** () > 0 and **height** () > 0\\. Note
        that non-trivial operations like intersections are not defined for
        invalid rectangles. A valid rectangle is not empty (i.e., isValid() ==
        !**isEmpty** ()).

        **See also** **isNull** (), **isEmpty** (), and **normalized** ().
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qrectf.html#isEmpty

        **bool QRectF::isEmpty() const**

        Returns `true` if the rectangle is empty, otherwise returns `false`.

        An empty rectangle has **width** () <= 0 or **height** () <= 0. An empty
        rectangle is not valid (i.e., isEmpty() == !**isValid** ()).

        Use the **normalized** () function to retrieve a rectangle where the
        corners are swapped.

        **See also** **isNull** (), **isValid** (), and **normalized** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qrectf.html#isNull

        **bool QRectF::isNull() const**

        Returns `true` if the rectangle is a null rectangle, otherwise returns
        `false`.

        A null rectangle has both the width and the height set to 0. A null
        rectangle is also empty, and hence not valid.

        **See also** **isEmpty** () and **isValid** ().
        """
        ...

    def intersects(self, r: "QRectF") -> bool:
        """
        https://doc.qt.io/qt-6/qrectf.html#intersects

        **bool QRectF::intersects(const QRectF & rectangle ) const**

        Returns `true` if this rectangle intersects with the given **rectangle**
        (i.e. there is a non-empty area of overlap between them), otherwise
        returns `false`.

        The intersection rectangle can be retrieved using the **intersected** ()
        function.

        **See also** **contains** ().
        """
        ...

    @typing.overload
    def __contains__(self, p: QPointF) -> int:
        ...

    @typing.overload
    def __contains__(self, r: "QRectF") -> int:
        ...

    @typing.overload
    def contains(self, p: QPointF) -> bool:
        """
        https://doc.qt.io/qt-6/qrectf.html#contains

        **bool QRectF::contains(const QPointF & point ) const**

        Returns `true` if the given **point** is inside or on the edge of the
        rectangle; otherwise returns `false`.

        **See also** **intersects** ().
        """
        ...

    @typing.overload
    def contains(self, r: "QRectF") -> bool:
        """
        https://doc.qt.io/qt-6/qrectf.html#contains-1

        **bool QRectF::contains(const QRectF & rectangle ) const**

        This is an overloaded function.

        Returns `true` if the given **rectangle** is inside this rectangle;
        otherwise returns `false`.
        """
        ...

    @typing.overload
    def contains(self, ax: float, ay: float) -> bool:
        """
        https://doc.qt.io/qt-6/qrectf.html#contains-2

        **bool QRectF::contains(qreal x , qreal y ) const**

        This is an overloaded function.

        Returns `true` if the point ( **x** , **y** ) is inside or on the edge
        of the rectangle; otherwise returns `false`.
        """
        ...

    def bottomLeft(self) -> QPointF:
        """
        https://doc.qt.io/qt-6/qrectf.html#bottomLeft

        **QPointF QRectF::bottomLeft() const**

        Returns the position of the rectangle's bottom-left corner.

        **See also** **setBottomLeft** (), **bottom** (), and **left** ().
        """
        ...

    def topRight(self) -> QPointF:
        """
        https://doc.qt.io/qt-6/qrectf.html#topRight

        **QPointF QRectF::topRight() const**

        Returns the position of the rectangle's top-right corner.

        **See also** **setTopRight** (), **top** (), and **right** ().
        """
        ...

    def bottomRight(self) -> QPointF:
        """
        https://doc.qt.io/qt-6/qrectf.html#bottomRight

        **QPointF QRectF::bottomRight() const**

        Returns the position of the rectangle's bottom-right corner.

        **See also** **setBottomRight** (), **bottom** (), and **right** ().
        """
        ...

    def topLeft(self) -> QPointF:
        """
        https://doc.qt.io/qt-6/qrectf.html#topLeft

        **QPointF QRectF::topLeft() const**

        Returns the position of the rectangle's top-left corner.

        **See also** **setTopLeft** (), **top** (), and **left** ().
        """
        ...

    def setY(self, pos: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setY

        **void QRectF::setY(qreal y )**

        Sets the top edge of the rectangle to the given finite **y** coordinate.
        May change the height, but will never change the bottom edge of the
        rectangle.

        Equivalent to **setTop** ().

        **See also** **y** (), **setX** (), and **setTopLeft** ().
        """
        ...

    def setX(self, pos: float) -> None:
        """
        https://doc.qt.io/qt-6/qrectf.html#setX

        **void QRectF::setX(qreal x )**

        Sets the left edge of the rectangle to the given finite **x**
        coordinate. May change the width, but will never change the right edge
        of the rectangle.

        Equivalent to **setLeft** ().

        **See also** **x** (), **setY** (), and **setTopLeft** ().
        """
        ...

    def bottom(self) -> float:
        """
        https://doc.qt.io/qt-6/qrectf.html#bottom

        **qreal QRectF::bottom() const**

        Returns the y-coordinate of the rectangle's bottom edge.

        **See also** **setBottom** (), **bottomLeft** (), and **bottomRight**
        ().
        """
        ...

    def right(self) -> float:
        """
        https://doc.qt.io/qt-6/qrectf.html#right

        **qreal QRectF::right() const**

        Returns the x-coordinate of the rectangle's right edge.

        **See also** **setRight** (), **topRight** (), and **bottomRight** ().
        """
        ...

    def top(self) -> float:
        """
        https://doc.qt.io/qt-6/qrectf.html#top

        **qreal QRectF::top() const**

        Returns the y-coordinate of the rectangle's top edge. Equivalent to
        **y** ().

        **See also** **setTop** (), **topLeft** (), and **topRight** ().
        """
        ...

    def left(self) -> float:
        """
        https://doc.qt.io/qt-6/qrectf.html#left

        **qreal QRectF::left() const**

        Returns the x-coordinate of the rectangle's left edge. Equivalent to
        **x** ().

        **See also** **setLeft** (), **topLeft** (), and **bottomLeft** ().
        """
        ...

    def normalized(self) -> "QRectF":
        """
        https://doc.qt.io/qt-6/qrectf.html#normalized

        **QRectF QRectF::normalized() const**

        Returns a normalized rectangle; i.e., a rectangle that has a non-
        negative width and height.

        If **width** () < 0 the function swaps the left and right corners, and
        it swaps the top and bottom corners if **height** () < 0.

        **See also** **isValid** () and **isEmpty** ().
        """
        ...

    def __repr__(self) -> str:
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtPositioning import *
import enum


class QGeoShape(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qgeoshape.html

    **Detailed Description**

    This class is the base class for classes which specify a geographic area.

    For the sake of consistency, subclasses should describe the specific details
    of the associated areas in terms of **QGeoCoordinate**  instances and
    distances in meters.

    This class is a **Q_GADGET**  since Qt 5.5. It can be **directly used from
    C++ and QML** .
    """

    class ShapeType(enum.Enum):
        UnknownType: QGeoShape = ...
        RectangleType: QGeoShape = ...
        CircleType: QGeoShape = ...
        PathType: QGeoShape = ...
        PolygonType: QGeoShape = ...

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qgeoshape.html#QGeoShape

        **QGeoShape::QGeoShape()**

        Constructs a new invalid geo shape of **UnknownType** .
        """
        ...

    @typing.overload
    def __init__(self, other: "QGeoShape") -> None:
        """
        https://doc.qt.io/qt-6/qgeoshape.html#QGeoShape-1

        **QGeoShape::QGeoShape(const QGeoShape & other )**

        Constructs a new geo shape which is a copy of **other**.
        """
        ...

    def __hash__(self) -> int:
        ...

    def boundingGeoRectangle(self) -> "QGeoRectangle":
        """
        https://doc.qt.io/qt-6/qgeoshape.html#boundingGeoRectangle

        **[invokable, since 5.9] QGeoRectangle QGeoShape::boundingGeoRectangle()
        const**

        Returns a **QGeoRectangle**  representing the geographical bounding
        rectangle of the geo shape, that defines the latitudinal/longitudinal
        bounds of the geo shape.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        This function was introduced in Qt 5.9.
        """
        ...

    def toString(self) -> str:
        """
        https://doc.qt.io/qt-6/qgeoshape.html#toString

        **[invokable, since 5.5] QString QGeoShape::toString() const**

        Returns a string representation of this geo shape.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .

        This function was introduced in Qt 5.5.
        """
        ...

    def center(self) -> "QGeoCoordinate":
        """
        https://doc.qt.io/qt-6/qgeoshape.html#center

        **[since 5.5] QGeoCoordinate QGeoShape::center() const**

        Returns the coordinate located at the geometric center of the geo shape.

        **Note:** Getter function for property **center** .

        This function was introduced in Qt 5.5.
        """
        ...

    def contains(self, coordinate: "QGeoCoordinate") -> bool:
        """
        https://doc.qt.io/qt-6/qgeoshape.html#contains

        **[invokable] bool QGeoShape::contains(const QGeoCoordinate & coordinate
        ) const**

        Returns whether the coordinate **coordinate** is contained within this
        geo shape.

        **Note:** This function can be invoked via the meta-object system and
        from QML. See **Q_INVOKABLE** .
        """
        ...

    def isEmpty(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgeoshape.html#isEmpty

        **bool QGeoShape::isEmpty() const**

        Returns whether this geo shape is empty.

        An empty geo shape is a region which has a geometrical area of 0.

        **Note:** Getter function for property **isEmpty** .
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgeoshape.html#isValid

        **bool QGeoShape::isValid() const**

        Returns whether this geo shape is valid.

        **Note:** Getter function for property **isValid** .
        """
        ...

    def type(self) -> "QGeoShape.ShapeType":
        """
        https://doc.qt.io/qt-6/qgeoshape.html#type

        **QGeoShape::ShapeType QGeoShape::type() const**

        Returns the type of this geo shape.

        **Note:** Getter function for property **type** .
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *


class QGraphicsWidget(QGraphicsObject, QGraphicsLayoutItem):
    """
    https://doc.qt.io/qt-6/qgraphicswidget.html

    **Detailed Description**

    QGraphicsWidget is an extended base item that provides extra functionality
    over **QGraphicsItem** . It is similar to **QWidget**  in many ways:

    * Provides a **palette** , a **font**  and a **style** ().
      * Has a defined
    **geometry** ().
      * Supports layouts with **setLayout** () and **layout**
    ().
      * Supports shortcuts and actions with **grabShortcut** () and
    **insertAction** ()

    Unlike **QGraphicsItem** , QGraphicsWidget is not an abstract class; you can
    create instances of a QGraphicsWidget without having to subclass it. This
    approach is useful for widgets that only serve the purpose of organizing
    child widgets into a layout.

    QGraphicsWidget can be used as a base item for your own custom item if you
    require advanced input focus handling, e.g., tab focus and activation, or
    layouts.

    Since QGraphicsWidget resembles **QWidget**  and has similar API, it is
    easier to port a widget from **QWidget**  to QGraphicsWidget, instead of
    **QGraphicsItem** .

    **Note:****QWidget** -based widgets can be directly embedded into a
    **QGraphicsScene**  using **QGraphicsProxyWidget** .

    Noticeable differences between QGraphicsWidget and **QWidget**  are:

    QGraphicsWidget**QWidget**
    Coordinates and geometry are defined with
    qreals (doubles or floats, depending on the platform).**QWidget**  uses
    integer geometry (**QPoint** , **QRect** ).
    The widget is already visible
    by default; you do not have to call **show** () to display the
    widget.**QWidget**  is hidden by default until you call **show** ().
    A
    subset of widget attributes are supported.All widget attributes are
    supported.
    A top-level item's style defaults to **QGraphicsScene::style**
    A top-level widget's style defaults to **QApplication::style**
    Graphics
    View provides a custom drag and drop framework, different from **QWidget**
    .Standard drag and drop framework.
    Widget items do not support
    modality.Full modality support.

    QGraphicsWidget supports a subset of Qt's widget attributes,
    (**Qt::WidgetAttribute** ), as shown in the table below. Any attributes not
    listed in this table are unsupported, or otherwise unused.

    Widget AttributeUsage
    **Qt::WA_SetLayoutDirection** Set by
    **setLayoutDirection** (), cleared by **unsetLayoutDirection** (). You can
    test this attribute to check if the widget has been explicitly assigned a
    **layoutDirection** . If the attribute is not set, the **layoutDirection**
    () is inherited.
    **Qt::WA_RightToLeft** Toggled by **setLayoutDirection**
    (). Inherited from the parent/scene. If set, the widget's layout will order
    horizontally arranged widgets from right to left.
    **Qt::WA_SetStyle** Set
    and cleared by **setStyle** (). If this attribute is set, the widget has
    been explicitly assigned a style. If it is unset, the widget will use the
    scene's or the application's style.
    **Qt::WA_Resized** Set by
    **setGeometry** () and **resize** ().
    **Qt::WA_SetPalette** Set by
    **setPalette** ().
    **Qt::WA_SetFont** Set by **setFont** ().
    **Qt::WA_WindowPropagation** Enables propagation to window widgets.

    Although QGraphicsWidget inherits from both **QObject**  and
    **QGraphicsItem** , you should use the functions provided by
    **QGraphicsItem** , **not** **QObject** , to manage the relationships
    between parent and child items. These functions control the stacking order
    of items as well as their ownership.

    **Note:** The **QObject::parent** () should always return `nullptr` for
    QGraphicsWidgets, but this policy is not strictly defined.

    **See also** **QGraphicsProxyWidget** , **QGraphicsItem** , and **Widgets
    and Layouts** .
    """

    def __init__(
        self,
        parent: typing.Optional[QGraphicsItem] = ...,
        flags: QtCore.Qt.WindowType = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#QGraphicsWidget

        **QGraphicsWidget::QGraphicsWidget(QGraphicsItem * parent = nullptr,
        Qt::WindowFlags wFlags = Qt::WindowFlags())**

        Constructs a QGraphicsWidget instance. The optional **parent** argument
        is passed to **QGraphicsItem** 's constructor. The optional **wFlags**
        argument specifies the widget's window flags (e.g., whether the widget
        should be a window, a tool, a popup, etc).
        """
        ...

    def setAutoFillBackground(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#autoFillBackground-prop

        **autoFillBackground : bool**

        This property holds whether the widget background is filled
        automatically

        If enabled, this property will cause Qt to fill the background of the
        widget before invoking the **paint** () method. The color used is
        defined by the **QPalette::Window**  color role from the widget's
        **palette** .

        In addition, Windows are always filled with **QPalette::Window** ,
        unless the WA_OpaquePaintEvent or WA_NoSystemBackground attributes are
        set.

        By default, this property is `false`.

        **Access functions:**

        bool **autoFillBackground** () const
        void **setAutoFillBackground**
        (bool **enabled** )

        **See also** **Qt::WA_OpaquePaintEvent**  and
        **Qt::WA_NoSystemBackground** .
        """
        ...

    def autoFillBackground(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#autoFillBackground-prop

        **autoFillBackground : bool**

        This property holds whether the widget background is filled
        automatically

        If enabled, this property will cause Qt to fill the background of the
        widget before invoking the **paint** () method. The color used is
        defined by the **QPalette::Window**  color role from the widget's
        **palette** .

        In addition, Windows are always filled with **QPalette::Window** ,
        unless the WA_OpaquePaintEvent or WA_NoSystemBackground attributes are
        set.

        By default, this property is `false`.

        **Access functions:**

        bool **autoFillBackground** () const
        void **setAutoFillBackground**
        (bool **enabled** )

        **See also** **Qt::WA_OpaquePaintEvent**  and
        **Qt::WA_NoSystemBackground** .
        """
        ...

    def ungrabKeyboardEvent(self, event: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#ungrabKeyboardEvent

        **[virtual protected] void QGraphicsWidget::ungrabKeyboardEvent(QEvent *
        event )**

        This event handler, for **event** , can be reimplemented in a subclass
        to receive notifications for **QEvent::UngrabKeyboard**  events.

        **See also** **ungrabKeyboard** () and **ungrabMouse** ().
        """
        ...

    def grabKeyboardEvent(self, event: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#grabKeyboardEvent

        **[virtual protected] void QGraphicsWidget::grabKeyboardEvent(QEvent *
        event )**

        This event handler, for **event** , can be reimplemented in a subclass
        to receive notifications for **QEvent::GrabKeyboard**  events.

        **See also** **grabKeyboard** () and **grabMouse** ().
        """
        ...

    def ungrabMouseEvent(self, event: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#ungrabMouseEvent

        **[virtual protected] void QGraphicsWidget::ungrabMouseEvent(QEvent *
        event )**

        This event handler, for **event** , can be reimplemented in a subclass
        to receive notifications for **QEvent::UngrabMouse**  events.

        **See also** **ungrabMouse** () and **ungrabKeyboard** ().
        """
        ...

    def grabMouseEvent(self, event: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#grabMouseEvent

        **[virtual protected] void QGraphicsWidget::grabMouseEvent(QEvent *
        event )**

        This event handler, for **event** , can be reimplemented in a subclass
        to receive notifications for **QEvent::GrabMouse**  events.

        **See also** **grabMouse** () and **grabKeyboard** ().
        """
        ...

    def hoverLeaveEvent(self, event: "QGraphicsSceneHoverEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#hoverLeaveEvent

        **[override virtual protected] void
        QGraphicsWidget::hoverLeaveEvent(QGraphicsSceneHoverEvent * event )**

        Reimplements: **QGraphicsItem::hoverLeaveEvent**
        (QGraphicsSceneHoverEvent *event).
        """
        ...

    def hoverMoveEvent(self, event: "QGraphicsSceneHoverEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#hoverMoveEvent

        **[override virtual protected] void
        QGraphicsWidget::hoverMoveEvent(QGraphicsSceneHoverEvent * event )**

        Reimplements: **QGraphicsItem::hoverMoveEvent**
        (QGraphicsSceneHoverEvent *event).
        """
        ...

    def showEvent(self, event: QtGui.QShowEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#showEvent

        **[virtual protected] void QGraphicsWidget::showEvent(QShowEvent * event
        )**

        This event handler, for **Show**  events, is delivered before the widget
        has been shown, for example, setVisible(true) has been called for the
        widget or one of its ancestors when the widget was previously hidden.

        You can reimplement this event handler to detect when your widget is
        shown. Calling **QEvent::accept** () or **QEvent::ignore** () on
        **event** has no effect.

        **See also** **hideEvent** (), **QWidget::showEvent** (), and
        **ItemVisibleChange** .
        """
        ...

    def resizeEvent(self, event: "QGraphicsSceneResizeEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#resizeEvent

        **[virtual protected] void
        QGraphicsWidget::resizeEvent(QGraphicsSceneResizeEvent * event )**

        This event handler, for **GraphicsSceneResize**  events, is delivered
        after the widget has been resized (i.e., its local size has changed).
        **event** contains both the old and the new size.

        This event is only delivered when the widget is resized locally; calling
        **setTransform** () on the widget or any of its ancestors or view, does
        not affect the widget's local size.

        You can reimplement this event handler to detect when your widget has
        been resized. Calling **QEvent::accept** () or **QEvent::ignore** () on
        **event** has no effect.

        **See also** **geometry** () and **setGeometry** ().
        """
        ...

    def polishEvent(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#polishEvent

        **[virtual protected] void QGraphicsWidget::polishEvent()**

        This event is delivered to the item by the scene at some point after it
        has been constructed, but before it is shown or otherwise accessed
        through the scene. You can use this event handler to do last-minute
        initializations of the widget which require the item to be fully
        constructed.

        The base implementation does nothing.
        """
        ...

    def moveEvent(self, event: "QGraphicsSceneMoveEvent") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#moveEvent

        **[virtual protected] void
        QGraphicsWidget::moveEvent(QGraphicsSceneMoveEvent * event )**

        This event handler, for **GraphicsSceneMove**  events, is delivered
        after the widget has moved (e.g., its local position has changed).

        This event is only delivered when the item is moved locally. Calling
        **setTransform** () or moving any of the item's ancestors does not
        affect the item's local position.

        You can reimplement this event handler to detect when your widget has
        moved. Calling **QEvent::accept** () or **QEvent::ignore** () on
        **event** has no effect.

        **See also** **ItemPositionChange**  and **ItemPositionHasChanged** .
        """
        ...

    def hideEvent(self, event: QtGui.QHideEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#hideEvent

        **[virtual protected] void QGraphicsWidget::hideEvent(QHideEvent * event
        )**

        This event handler, for **Hide**  events, is delivered after the widget
        has been hidden, for example, setVisible(false) has been called for the
        widget or one of its ancestors when the widget was previously shown.

        You can reimplement this event handler to detect when your widget is
        hidden. Calling **QEvent::accept** () or **QEvent::ignore** () on
        **event** has no effect.

        **See also** **showEvent** (), **QWidget::hideEvent** (), and
        **ItemVisibleChange** .
        """
        ...

    def focusOutEvent(self, event: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#focusOutEvent

        **[override virtual protected] void
        QGraphicsWidget::focusOutEvent(QFocusEvent * event )**

        Reimplements: **QGraphicsItem::focusOutEvent** (QFocusEvent *event).
        """
        ...

    def focusNextPrevChild(self, next: bool) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#focusNextPrevChild

        **[virtual protected] bool QGraphicsWidget::focusNextPrevChild(bool next
        )**

        Finds a new widget to give the keyboard focus to, as appropriate for Tab
        and Shift+Tab, and returns `true` if it can find a new widget; returns
        `false` otherwise. If **next** is true, this function searches forward;
        if **next** is false, it searches backward.

        Sometimes, you will want to reimplement this function to provide special
        focus handling for your widget and its subwidgets. For example, a web
        browser might reimplement it to move its current active link forward or
        backward, and call the base implementation only when it reaches the last
        or first link on the page.

        Child widgets call focusNextPrevChild() on their parent widgets, but
        only the window that contains the child widgets decides where to
        redirect focus. By reimplementing this function for an object, you gain
        control of focus traversal for all child widgets.

        **See also** **focusPolicy** ().
        """
        ...

    def focusInEvent(self, event: QtGui.QFocusEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#focusInEvent

        **[override virtual protected] void
        QGraphicsWidget::focusInEvent(QFocusEvent * event )**

        Reimplements: **QGraphicsItem::focusInEvent** (QFocusEvent *event).
        """
        ...

    def closeEvent(self, event: QtGui.QCloseEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#closeEvent

        **[virtual protected] void QGraphicsWidget::closeEvent(QCloseEvent *
        event )**

        This event handler, for **event** , can be reimplemented in a subclass
        to receive widget close events. The default implementation accepts the
        event.

        **See also** **close** () and **QCloseEvent** .
        """
        ...

    def changeEvent(self, event: QtCore.QEvent) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#changeEvent

        **[virtual protected] void QGraphicsWidget::changeEvent(QEvent * event
        )**

        This event handler can be reimplemented to handle state changes.

        The state being changed in this event can be retrieved through
        **event**.

        Change events include: **QEvent::ActivationChange** ,
        **QEvent::EnabledChange** , **QEvent::FontChange** ,
        **QEvent::StyleChange** , **QEvent::PaletteChange** ,
        **QEvent::ParentChange** , **QEvent::LayoutDirectionChange** , and
        **QEvent::ContentsRectChange** .
        """
        ...

    def event(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#event

        **[override virtual protected] bool QGraphicsWidget::event(QEvent *
        event )**

        Reimplements: **QGraphicsObject::event** (QEvent *ev).

        Handles the **event**. **QGraphicsWidget**  handles the following
        events:

        EventUsage
        PolishDelivered to the widget some time after it has been
        shown.
        GraphicsSceneMoveDelivered to the widget after its local
        position has changed.
        GraphicsSceneResizeDelivered to the widget after
        its size has changed.
        ShowDelivered to the widget before it has been
        shown.
        HideDelivered to the widget after it has been hidden.
        PaletteChangeDelivered to the widget after its palette has changed.
        FontChangeDelivered to the widget after its font has changed.
        EnabledChangeDelivered to the widget after its enabled state has
        changed.
        StyleChangeDelivered to the widget after its style has
        changed.
        LayoutDirectionChangeDelivered to the widget after its layout
        direction has changed.
        ContentsRectChangeDelivered to the widget after
        its contents margins/ contents rect has changed.
        """
        ...

    def windowFrameSectionAt(self, pos: QtCore.QPointF) -> QtCore.Qt.WindowFrameSection:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#windowFrameSectionAt

        **[virtual protected] Qt::WindowFrameSection
        QGraphicsWidget::windowFrameSectionAt(const QPointF & pos ) const**

        Returns the window frame section at position **pos** , or
        **Qt::NoSection**  if there is no window frame section at this position.

        This function is used in **QGraphicsWidget** 's base implementation for
        window frame interaction.

        You can reimplement this function if you want to customize how a window
        can be interactively moved or resized. For instance, if you only want to
        allow a window to be resized by the bottom right corner, you can
        reimplement this function to return **Qt::NoSection**  for all sections
        except **Qt::BottomRightSection** .

        **See also** **windowFrameEvent** (), **paintWindowFrame** (), and
        **windowFrameGeometry** ().
        """
        ...

    def windowFrameEvent(self, e: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#windowFrameEvent

        **[virtual protected] bool QGraphicsWidget::windowFrameEvent(QEvent *
        event )**

        This event handler, for **event** , receives events for the window frame
        if this widget is a window. Its base implementation provides support for
        default window frame interaction such as moving, resizing, etc.

        You can reimplement this handler in a subclass of **QGraphicsWidget**
        to provide your own custom window frame interaction support.

        Returns `true` if **event** has been recognized and processed;
        otherwise, returns `false`.

        **See also** **event** ().
        """
        ...

    def sceneEvent(self, event: QtCore.QEvent) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#sceneEvent

        **[override virtual protected] bool QGraphicsWidget::sceneEvent(QEvent *
        event )**

        Reimplements: **QGraphicsItem::sceneEvent** (QEvent *event).

        **QGraphicsWidget** 's implementation of sceneEvent() simply passes
        **event** to **QGraphicsWidget::event** (). You can handle all events
        for your widget in **event** () or in any of the convenience functions;
        you should not have to reimplement this function in a subclass of
        **QGraphicsWidget** .

        Returns `true` if **event** has been recognized and processed;
        otherwise, returns `false`.

        **See also** **QGraphicsItem::sceneEvent** ().
        """
        ...

    def itemChange(
        self, change: QGraphicsItem.GraphicsItemChange, value: typing.Any
    ) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#itemChange

        **[override virtual protected] QVariant
        QGraphicsWidget::itemChange(QGraphicsItem::GraphicsItemChange change ,
        const QVariant & value )**

        Reimplements: **QGraphicsItem::itemChange**
        (QGraphicsItem::GraphicsItemChange change, const QVariant &value).

        **QGraphicsWidget**  uses the base implementation of this function to
        catch and deliver events related to state changes in the item. Because
        of this, it is very important that subclasses call the base
        implementation.

        **change** specifies the type of change, and **value** is the new value.

        For example, **QGraphicsWidget**  uses ItemVisibleChange to deliver
        **Show**  and **Hide**  events, ItemPositionHasChanged to deliver
        **Move**  events, and ItemParentChange both to deliver **ParentChange**
        events, and for managing the focus chain.

        **QGraphicsWidget**  enables the ItemSendsGeometryChanges flag by
        default in order to track position changes.

        **See also** **QGraphicsItem::itemChange** ().
        """
        ...

    def updateGeometry(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#updateGeometry

        **[override virtual protected] void QGraphicsWidget::updateGeometry()**

        Reimplements: **QGraphicsLayoutItem::updateGeometry** ().

        If this widget is currently managed by a layout, this function notifies
        the layout that the widget's size hints have changed and the layout may
        need to resize and reposition the widget accordingly.

        Call this function if the widget's **sizeHint** () has changed.

        **See also** **QGraphicsLayout::invalidate** ().
        """
        ...

    def sizeHint(
        self, which: QtCore.Qt.SizeHint, constraint: QtCore.QSizeF = ...
    ) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#sizeHint

        **[override virtual protected] QSizeF
        QGraphicsWidget::sizeHint(Qt::SizeHint which , const QSizeF & constraint
        = QSizeF()) const**

        Reimplements: **QGraphicsLayoutItem::sizeHint(Qt::SizeHint which, const
        QSizeF &constraint) const** .
        """
        ...

    def initStyleOption(self, option: "QStyleOption") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#initStyleOption

        **[virtual protected] void QGraphicsWidget::initStyleOption(QStyleOption
        * option ) const**

        Populates a style option object for this widget based on its current
        state, and stores the output in **option**. The default implementation
        populates **option** with the following properties.

        Style Option PropertyValue
        state & **QStyle::State_Enabled**
        Corresponds to **QGraphicsItem::isEnabled** ().
        state &
        **QStyle::State_HasFocus** Corresponds to **QGraphicsItem::hasFocus**
        ().
        state & **QStyle::State_MouseOver** Corresponds to
        **QGraphicsItem::isUnderMouse** ().
        directionCorresponds to
        **QGraphicsWidget::layoutDirection** ().
        rectCorresponds to
        **QGraphicsWidget::rect** ().toRect().
        paletteCorresponds to
        **QGraphicsWidget::palette** ().
        fontMetricsCorresponds to
        **QFontMetrics** (**QGraphicsWidget::font** ()).

        Subclasses of **QGraphicsWidget**  should call the base implementation,
        and then test the type of **option** using **qstyleoption_cast** <>() or
        test **QStyleOption::Type**  before storing widget-specific options.

        For example:

        void MyGroupBoxWidget::initStyleOption(**QStyleOption**  *option) const
        {
                **QGraphicsWidget** ::initStyleOption(option);
                if
        (**QStyleOptionGroupBox**  *box =
        qstyleoption_cast<**QStyleOptionGroupBox**  \\*>(option)) {
        // Add group box specific state.
                    box->flat = isFlat();
        ...
                }
            }

        **See also** **QStyleOption::initFrom** ().
        """
        ...

    def close(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#close

        **[slot] bool QGraphicsWidget::close()**

        Call this function to close the widget.

        Returns `true` if the widget was closed; otherwise returns `false`. This
        slot will first send a **QCloseEvent**  to the widget, which may or may
        not accept the event. If the event was ignored, nothing happens. If the
        event was accepted, it will **hide** () the widget.

        If the widget has the **Qt::WA_DeleteOnClose**  attribute set it will be
        deleted.
        """
        ...

    def shape(self) -> QtGui.QPainterPath:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#shape

        **[override virtual] QPainterPath QGraphicsWidget::shape() const**

        Reimplements: **QGraphicsItem::shape() const** .
        """
        ...

    def boundingRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#boundingRect

        **[override virtual] QRectF QGraphicsWidget::boundingRect() const**

        Reimplements: **QGraphicsItem::boundingRect() const** .
        """
        ...

    def paintWindowFrame(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionGraphicsItem",
        widget: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#paintWindowFrame

        **[virtual] void QGraphicsWidget::paintWindowFrame(QPainter * painter ,
        const QStyleOptionGraphicsItem * option , QWidget * widget = nullptr)**

        This virtual function is called by **QGraphicsScene**  to draw the
        window frame for windows using **painter** , **option** , and **widget**
        , in local coordinates. The base implementation uses the current style
        to render the frame and title bar.

        You can reimplement this function in a subclass of **QGraphicsWidget**
        to provide custom rendering of the widget's window frame.

        **See also** **QGraphicsItem::paint** ().
        """
        ...

    def paint(
        self,
        painter: QtGui.QPainter,
        option: "QStyleOptionGraphicsItem",
        widget: typing.Optional[QWidget] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#paint

        **[override virtual] void QGraphicsWidget::paint(QPainter * painter ,
        const QStyleOptionGraphicsItem * option , QWidget * widget = nullptr)**

        Reimplements: **QGraphicsItem::paint** (QPainter *painter, const
        QStyleOptionGraphicsItem *option, QWidget *widget).
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#type

        **[override virtual] int QGraphicsWidget::type() const**

        Reimplements: **QGraphicsItem::type() const** .
        """
        ...

    def testAttribute(self, attribute: QtCore.Qt.WidgetAttribute) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#testAttribute

        **bool QGraphicsWidget::testAttribute(Qt::WidgetAttribute attribute )
        const**

        Returns `true` if **attribute** is enabled for this widget; otherwise,
        returns `false`.

        **See also** **setAttribute** ().
        """
        ...

    def setAttribute(
        self, attribute: QtCore.Qt.WidgetAttribute, on: bool = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#setAttribute

        **void QGraphicsWidget::setAttribute(Qt::WidgetAttribute attribute ,
        bool on = true)**

        If **on** is true, this function enables **attribute** ; otherwise
        **attribute** is disabled.

        See the class documentation for **QGraphicsWidget**  for a complete list
        of which attributes are supported, and what they are for.

        **See also** **testAttribute** () and **QWidget::setAttribute** ().
        """
        ...

    def actions(self) -> typing.List[QtGui.QAction]:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#actions

        **QList<QAction *> QGraphicsWidget::actions() const**

        Returns the (possibly empty) list of this widget's actions.

        **See also** **insertAction** (), **removeAction** (),
        **QWidget::actions** (), **QAction::associatedWidgets** (), and
        **QAction::associatedGraphicsWidgets** ().
        """
        ...

    def removeAction(self, action: QtGui.QAction) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#removeAction

        **void QGraphicsWidget::removeAction(QAction * action )**

        Removes the action **action** from this widget's list of actions.

        **See also** **insertAction** (), **actions** (), **insertAction** (),
        and **QWidget::removeAction** ().
        """
        ...

    def insertActions(
        self, before: QtGui.QAction, actions: typing.Iterable[QtGui.QAction]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#insertActions

        **void QGraphicsWidget::insertActions(QAction * before , const
        QList<QAction *> & actions )**

        Inserts the actions **actions** to this widget's list of actions, before
        the action **before**. It appends the action if **before** is `nullptr`
        or **before** is not a valid action for this widget.

        A **QGraphicsWidget**  can have at most one of each action.

        **See also** **removeAction** (), **QMenu** , **insertAction** (), and
        **QWidget::insertActions** ().
        """
        ...

    def insertAction(self, before: QtGui.QAction, action: QtGui.QAction) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#insertAction

        **void QGraphicsWidget::insertAction(QAction * before , QAction * action
        )**

        Inserts the action **action** to this widget's list of actions, before
        the action **before**. It appends the action if **before** is `nullptr`
        or **before** is not a valid action for this widget.

        A **QGraphicsWidget**  should only have one of each action.

        **See also** **removeAction** (), **addAction** (), **QMenu** ,
        **actions** (), and **QWidget::insertActions** ().
        """
        ...

    def addActions(self, actions: typing.Iterable[QtGui.QAction]) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#addActions

        **void QGraphicsWidget::addActions(const QList<QAction *> & actions )**

        Appends the actions **actions** to this widget's list of actions.

        **See also** **removeAction** (), **QMenu** , **addAction** (), and
        **QWidget::addActions** ().
        """
        ...

    def addAction(self, action: QtGui.QAction) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#addAction

        **void QGraphicsWidget::addAction(QAction * action )**

        Appends the action **action** to this widget's list of actions.

        All QGraphicsWidgets have a list of **QAction** s, however they can be
        represented graphically in many different ways. The default use of the
        **QAction**  list (as returned by **actions** ()) is to create a context
        **QMenu** .

        A **QGraphicsWidget**  should only have one of each action and adding an
        action it already has will not cause the same action to be in the widget
        twice.

        **See also** **removeAction** (), **insertAction** (), **actions** (),
        and **QWidget::addAction** ().
        """
        ...

    def setShortcutAutoRepeat(self, id: int, enabled: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#setShortcutAutoRepeat

        **void QGraphicsWidget::setShortcutAutoRepeat(int id , bool enabled =
        true)**

        If **enabled** is true, auto repeat of the shortcut with the given
        **id** is enabled; otherwise it is disabled.

        **See also** **grabShortcut** (), **releaseShortcut** (), and
        **QWidget::setShortcutAutoRepeat** ().
        """
        ...

    def setShortcutEnabled(self, id: int, enabled: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#setShortcutEnabled

        **void QGraphicsWidget::setShortcutEnabled(int id , bool enabled =
        true)**

        If **enabled** is true, the shortcut with the given **id** is enabled;
        otherwise the shortcut is disabled.

        **Warning:** You should not normally need to use this function since
        Qt's shortcut system enables/disables shortcuts automatically as widgets
        become hidden/visible and gain or lose focus. It is best to use
        **QAction**  or **QShortcut**  to handle shortcuts, since they are
        easier to use than this low-level function.

        **See also** **grabShortcut** (), **releaseShortcut** (), and
        **QWidget::setShortcutEnabled** ().
        """
        ...

    def releaseShortcut(self, id: int) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#releaseShortcut

        **void QGraphicsWidget::releaseShortcut(int id )**

        Removes the shortcut with the given **id** from Qt's shortcut system.
        The widget will no longer receive **QEvent::Shortcut**  events for the
        shortcut's key sequence (unless it has other shortcuts with the same key
        sequence).

        **Warning:** You should not normally need to use this function since
        Qt's shortcut system removes shortcuts automatically when their parent
        widget is destroyed. It is best to use **QAction**  or **QShortcut**  to
        handle shortcuts, since they are easier to use than this low-level
        function. Note also that this is an expensive operation.

        **See also** **grabShortcut** (), **setShortcutEnabled** (), and
        **QWidget::releaseShortcut** ().
        """
        ...

    def grabShortcut(
        self,
        sequence: typing.Union[
            QtGui.QKeySequence, QtGui.QKeySequence.StandardKey, str, int
        ],
        context: QtCore.Qt.ShortcutContext = ...,
    ) -> int:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#grabShortcut

        **int QGraphicsWidget::grabShortcut(const QKeySequence & sequence ,
        Qt::ShortcutContext context = Qt::WindowShortcut)**

        Adds a shortcut to Qt's shortcut system that watches for the given key
        **sequence** in the given **context**. If the **context** is
        **Qt::ApplicationShortcut** , the shortcut applies to the application as
        a whole. Otherwise, it is either local to this widget,
        **Qt::WidgetShortcut** , or to the window itself, **Qt::WindowShortcut**
        . For widgets that are not part of a window (i.e., top-level widgets and
        their children), **Qt::WindowShortcut**  shortcuts apply to the scene.

        If the same key **sequence** has been grabbed by several widgets, when
        the key **sequence** occurs a **QEvent::Shortcut**  event is sent to all
        the widgets to which it applies in a non-deterministic order, but with
        the ``ambiguous'' flag set to true.

        **Warning:** You should not normally need to use this function; instead
        create **QAction** s with the shortcut key sequences you require (if you
        also want equivalent menu options and toolbar buttons), or create
        **QShortcut** s if you just need key sequences. Both **QAction**  and
        **QShortcut**  handle all the event filtering for you, and provide
        signals which are triggered when the user triggers the key sequence, so
        are much easier to use than this low-level function.

        **See also** **releaseShortcut** (), **setShortcutEnabled** (), and
        **QWidget::grabShortcut** ().
        """
        ...

    def focusWidget(self) -> "QGraphicsWidget":
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#focusWidget

        **QGraphicsWidget *QGraphicsWidget::focusWidget() const**

        If this widget, a child or descendant of this widget currently has input
        focus, this function will return a pointer to that widget. If no
        descendant widget has input focus, `nullptr` is returned.

        **See also** **QGraphicsItem::focusItem** () and
        **QWidget::focusWidget** ().
        """
        ...

    @staticmethod
    def setTabOrder(first: "QGraphicsWidget", second: "QGraphicsWidget") -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#setTabOrder

        **[static] void QGraphicsWidget::setTabOrder(QGraphicsWidget * first ,
        QGraphicsWidget * second )**

        Moves the **second** widget around the ring of focus widgets so that
        keyboard focus moves from the **first** widget to the **second** widget
        when the Tab key is pressed.

        Note that since the tab order of the **second** widget is changed, you
        should order a chain like this:

        setTabOrder(a, b); // a to b
            setTabOrder(b, c); // a to b to c
        setTabOrder(c, d); // a to b to c to d

        **not** like this:

        // WRONG
            setTabOrder(c, d); // c to d
            setTabOrder(a, b); // a to
        b AND c to d
            setTabOrder(b, c); // a to b to c, but not c to d

        If **first** is `nullptr`, this indicates that **second** should be the
        first widget to receive input focus should the scene gain Tab focus
        (i.e., the user hits Tab so that focus passes into the scene). If
        **second** is `nullptr`, this indicates that **first** should be the
        first widget to gain focus if the scene gained BackTab focus.

        By default, tab order is defined implicitly using widget creation order.

        **See also** **focusPolicy**  and **Keyboard Focus in Widgets** .
        """
        ...

    def setFocusPolicy(self, policy: QtCore.Qt.FocusPolicy) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#focusPolicy-prop

        **focusPolicy : Qt::FocusPolicy**

        This property holds the way the widget accepts keyboard focus

        The focus policy is **Qt::TabFocus**  if the widget accepts keyboard
        focus by tabbing, **Qt::ClickFocus**  if the widget accepts focus by
        clicking, **Qt::StrongFocus**  if it accepts both, and **Qt::NoFocus**
        (the default) if it does not accept focus at all.

        You must enable keyboard focus for a widget if it processes keyboard
        events. This is normally done from the widget's constructor. For
        instance, the **QLineEdit**  constructor calls
        setFocusPolicy(**Qt::StrongFocus** ).

        If you enable a focus policy (i.e., not **Qt::NoFocus** ),
        **QGraphicsWidget**  will automatically enable the ItemIsFocusable flag.
        Setting **Qt::NoFocus**  on a widget will clear the ItemIsFocusable
        flag. If the widget currently has keyboard focus, the widget will
        automatically lose focus.

        **Access functions:**

        Qt::FocusPolicy **focusPolicy** () const
        void **setFocusPolicy**
        (Qt::FocusPolicy **policy** )

        **See also** **focusInEvent** (), **focusOutEvent** (),
        **keyPressEvent** (), **keyReleaseEvent** (), and **enabled** .
        """
        ...

    def focusPolicy(self) -> QtCore.Qt.FocusPolicy:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#focusPolicy-prop

        **focusPolicy : Qt::FocusPolicy**

        This property holds the way the widget accepts keyboard focus

        The focus policy is **Qt::TabFocus**  if the widget accepts keyboard
        focus by tabbing, **Qt::ClickFocus**  if the widget accepts focus by
        clicking, **Qt::StrongFocus**  if it accepts both, and **Qt::NoFocus**
        (the default) if it does not accept focus at all.

        You must enable keyboard focus for a widget if it processes keyboard
        events. This is normally done from the widget's constructor. For
        instance, the **QLineEdit**  constructor calls
        setFocusPolicy(**Qt::StrongFocus** ).

        If you enable a focus policy (i.e., not **Qt::NoFocus** ),
        **QGraphicsWidget**  will automatically enable the ItemIsFocusable flag.
        Setting **Qt::NoFocus**  on a widget will clear the ItemIsFocusable
        flag. If the widget currently has keyboard focus, the widget will
        automatically lose focus.

        **Access functions:**

        Qt::FocusPolicy **focusPolicy** () const
        void **setFocusPolicy**
        (Qt::FocusPolicy **policy** )

        **See also** **focusInEvent** (), **focusOutEvent** (),
        **keyPressEvent** (), **keyReleaseEvent** (), and **enabled** .
        """
        ...

    def windowTitle(self) -> str:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#windowTitle-prop

        **windowTitle : QString**

        This property holds the window title (caption).

        This property is only used for windows.

        By default, if no title has been set, this property contains an empty
        string.

        **Access functions:**

        QString **windowTitle** () const
        void **setWindowTitle** (const
        QString & **title** )

        **Member Function Documentation**
        """
        ...

    def setWindowTitle(self, title: str) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#windowTitle-prop

        **windowTitle : QString**

        This property holds the window title (caption).

        This property is only used for windows.

        By default, if no title has been set, this property contains an empty
        string.

        **Access functions:**

        QString **windowTitle** () const
        void **setWindowTitle** (const
        QString & **title** )

        **Member Function Documentation**
        """
        ...

    def isActiveWindow(self) -> bool:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#isActiveWindow

        **bool QGraphicsWidget::isActiveWindow() const**

        Returns `true` if this widget's window is in the active window, or if
        the widget does not have a window but is in an active scene (i.e., a
        scene that currently has focus).

        The active window is the window that either contains a child widget that
        currently has input focus, or that itself has input focus.

        **See also** **QGraphicsScene::activeWindow** (),
        **QGraphicsScene::setActiveWindow** (), and **isActive** ().
        """
        ...

    def setWindowFlags(self, wFlags: QtCore.Qt.WindowType) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#windowFlags-prop

        **windowFlags : Qt::WindowFlags**

        This property holds the widget's window flags

        Window flags are a combination of a window type (e.g., **Qt::Dialog** )
        and several flags giving hints on the behavior of the window. The
        behavior is platform-dependent.

        By default, this property contains no window flags.

        Windows are panels. If you set the **Qt::Window**  flag, the ItemIsPanel
        flag will be set automatically. If you clear the **Qt::Window**  flag,
        the ItemIsPanel flag is also cleared. Note that the ItemIsPanel flag can
        be set independently of **Qt::Window** .

        **Access functions:**

        Qt::WindowFlags **windowFlags** () const
        void **setWindowFlags**
        (Qt::WindowFlags **wFlags** )

        **See also** **isWindow** () and **isPanel** ().
        """
        ...

    def windowType(self) -> QtCore.Qt.WindowType:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#windowType

        **Qt::WindowType QGraphicsWidget::windowType() const**

        Returns the widgets window type.

        **See also** **windowFlags** (), **isWindow** (), and **isPanel** ().
        """
        ...

    def windowFlags(self) -> QtCore.Qt.WindowType:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#windowFlags-prop

        **windowFlags : Qt::WindowFlags**

        This property holds the widget's window flags

        Window flags are a combination of a window type (e.g., **Qt::Dialog** )
        and several flags giving hints on the behavior of the window. The
        behavior is platform-dependent.

        By default, this property contains no window flags.

        Windows are panels. If you set the **Qt::Window**  flag, the ItemIsPanel
        flag will be set automatically. If you clear the **Qt::Window**  flag,
        the ItemIsPanel flag is also cleared. Note that the ItemIsPanel flag can
        be set independently of **Qt::Window** .

        **Access functions:**

        Qt::WindowFlags **windowFlags** () const
        void **setWindowFlags**
        (Qt::WindowFlags **wFlags** )

        **See also** **isWindow** () and **isPanel** ().
        """
        ...

    def windowFrameRect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#windowFrameRect

        **QRectF QGraphicsWidget::windowFrameRect() const**

        Returns the widget's local rect including any window frame.

        **See also** **windowFrameGeometry** (), **getWindowFrameMargins** (),
        and **setWindowFrameMargins** ().
        """
        ...

    def windowFrameGeometry(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#windowFrameGeometry

        **QRectF QGraphicsWidget::windowFrameGeometry() const**

        Returns the widget's geometry in parent coordinates including any window
        frame.

        **See also** **windowFrameRect** (), **getWindowFrameMargins** (), and
        **setWindowFrameMargins** ().
        """
        ...

    def unsetWindowFrameMargins(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#unsetWindowFrameMargins

        **void QGraphicsWidget::unsetWindowFrameMargins()**

        Resets the window frame margins to the default value, provided by the
        style.

        **See also** **setWindowFrameMargins** (), **getWindowFrameMargins** (),
        and **windowFrameRect** ().
        """
        ...

    def getWindowFrameMargins(self) -> typing.Tuple[float, float, float, float]:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#getWindowFrameMargins

        **void QGraphicsWidget::getWindowFrameMargins(qreal * left , qreal * top
        , qreal * right , qreal * bottom ) const**

        Gets the widget's window frame margins. The margins are stored in
        **left** , **top** , **right** and **bottom** as pointers to qreals.
        Each argument can be **omitted** by passing `nullptr`.

        **See also** **setWindowFrameMargins** () and **windowFrameRect** ().
        """
        ...

    @typing.overload
    def setWindowFrameMargins(self, margins: QtCore.QMarginsF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#setWindowFrameMargins

        **[since 5.14] void QGraphicsWidget::setWindowFrameMargins(QMarginsF
        margins )**

        Sets the widget's window frame margins to **margins**. The default frame
        margins are provided by the style, and they depend on the current window
        flags.

        If you would like to draw your own window decoration, you can set your
        own frame margins to override the default margins.

        This function was introduced in Qt 5.14.

        **See also** **unsetWindowFrameMargins** (), **getWindowFrameMargins**
        (), and **windowFrameRect** ().
        """
        ...

    @typing.overload
    def setWindowFrameMargins(
        self, left: float, top: float, right: float, bottom: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#setWindowFrameMargins-1

        **void QGraphicsWidget::setWindowFrameMargins(qreal left , qreal top ,
        qreal right , qreal bottom )**

        This is an overloaded function.

        Sets the widget's window frame margins to **left** , **top** , **right**
        and **bottom**.
        """
        ...

    def getContentsMargins(self) -> typing.Tuple[float, float, float, float]:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#getContentsMargins

        **[override virtual] void QGraphicsWidget::getContentsMargins(qreal *
        left , qreal * top , qreal * right , qreal * bottom ) const**

        Reimplements: **QGraphicsLayoutItem::getContentsMargins(qreal *left,
        qreal *top, qreal *right, qreal *bottom) const** .

        Gets the widget's contents margins. The margins are stored in **left** ,
        **top** , **right** and **bottom** , as pointers to qreals. Each
        argument can be **omitted** by passing `nullptr`.

        **See also** **setContentsMargins** ().
        """
        ...

    @typing.overload
    def setContentsMargins(self, margins: QtCore.QMarginsF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#setContentsMargins

        **[since 5.14] void QGraphicsWidget::setContentsMargins(QMarginsF
        margins )**

        Sets the widget's contents margins to **margins**.

        Contents margins are used by the assigned layout to define the placement
        of subwidgets and layouts. Margins are particularly useful for widgets
        that constrain subwidgets to only a section of its own geometry. For
        example, a group box with a layout will place subwidgets inside its
        frame, but below the title.

        Changing a widget's contents margins will always trigger an **update**
        (), and any assigned layout will be activated automatically. The widget
        will then receive a **ContentsRectChange**  event.

        This function was introduced in Qt 5.14.

        **See also** **getContentsMargins** () and **setGeometry** ().
        """
        ...

    @typing.overload
    def setContentsMargins(
        self, left: float, top: float, right: float, bottom: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#setContentsMargins-1

        **void QGraphicsWidget::setContentsMargins(qreal left , qreal top ,
        qreal right , qreal bottom )**

        This is an overloaded function.

        Sets the widget's contents margins to **left** , **top** , **right** and
        **bottom**.
        """
        ...

    def rect(self) -> QtCore.QRectF:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#rect

        **QRectF QGraphicsWidget::rect() const**

        Returns the item's local rect as a **QRectF** . This function is
        equivalent to **QRectF** (QPointF(), **size** ()).

        **See also** **setGeometry** () and **resize** ().
        """
        ...

    @typing.overload
    def setGeometry(self, rect: QtCore.QRectF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#setGeometry-1

        **void QGraphicsWidget::setGeometry(qreal x , qreal y , qreal w , qreal
        h )**

        This convenience function is equivalent to calling
        setGeometry(**QRectF** ( **x** , **y** , **w** , **h** )).

        **Note:** Setter function for property **geometry** .

        **See also** **geometry** () and **resize** ().
        """
        ...

    @typing.overload
    def setGeometry(self, ax: float, ay: float, aw: float, ah: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#geometry-prop

        **geometry : QRectF**

        This property holds the geometry of the widget

        Sets the item's geometry to **rect**. The item's position and size are
        modified as a result of calling this function. The item is first moved,
        then resized.

        A side effect of calling this function is that the widget will receive a
        move event and a resize event. Also, if the widget has a layout
        assigned, the layout will activate.

        **Access functions:**

        virtual void **setGeometry** (const QRectF & **rect** ) override
        void
        ****setGeometry** ** (qreal **x** , qreal **y** , qreal **w** , qreal
        **h** )

        **Notifier signal:**

        void ****geometryChanged** ** ()

        **See also** **geometry** () and **resize** ().
        """
        ...

    def size(self) -> QtCore.QSizeF:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#size-prop

        **size : QSizeF**

        This property holds the size of the widget

        Calling resize() resizes the widget to a **size** bounded by
        **minimumSize** () and **maximumSize** (). This property only affects
        the widget's width and height (e.g., its right and bottom edges); the
        widget's position and top-left corner remains unaffected.

        Resizing a widget triggers the widget to immediately receive a
        **GraphicsSceneResize**  event with the widget's old and new size. If
        the widget has a layout assigned when this event arrives, the layout
        will be activated and it will automatically update any child widgets's
        geometry.

        This property does not affect any layout of the parent widget. If the
        widget itself is managed by a parent layout; e.g., it has a parent
        widget with a layout assigned, that layout will not activate.

        By default, this property contains a size with zero width and height.

        **Access functions:**

        QSizeF **size** () const
        void **resize** (const QSizeF & **size** )
        void ****resize** ** (qreal **w** , qreal **h** )

        **Notifier signal:**

        void ****geometryChanged** ** ()

        **See also** **setGeometry** (), **QGraphicsSceneResizeEvent** , and
        **QGraphicsLayout** .
        """
        ...

    @typing.overload
    def resize(self, size: QtCore.QSizeF) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#resize-1

        **void QGraphicsWidget::resize(qreal w , qreal h )**

        This is an overloaded function.

        Constructs a resize with the given `width` ( **w** ) and `height` (
        **h** ). This convenience function is equivalent to calling
        resize(**QSizeF** (w, h)).

        **Note:** Setter function for property **size** .

        **See also** **setGeometry** () and **setTransform** ().
        """
        ...

    @typing.overload
    def resize(self, w: float, h: float) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#resize-1

        **void QGraphicsWidget::resize(qreal w , qreal h )**

        This is an overloaded function.

        Constructs a resize with the given `width` ( **w** ) and `height` (
        **h** ). This convenience function is equivalent to calling
        resize(**QSizeF** (w, h)).

        **Note:** Setter function for property **size** .

        **See also** **setGeometry** () and **setTransform** ().
        """
        ...

    def setPalette(self, palette: QtGui.QPalette) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#palette-prop

        **palette : QPalette**

        This property holds the widget's palette

        This property provides the widget's palette. The palette provides colors
        and brushes for color groups (e.g., **QPalette::Button** ) and states
        (e.g., **QPalette::Inactive** ), loosely defining the general look of
        the widget and its children.

        **QPalette**  consists of color groups that have been explicitly
        defined, and groups that are implicitly inherited from the widget's
        parent. Because of this, palette() can return a different palette than
        what has been set with setPalette(). This scheme allows you to define
        single entries in a palette without affecting the palette's inherited
        entries.

        When a widget's palette changes, it resolves its entries against its
        parent widget, or if it doesn't have a parent widget, it resolves
        against the scene. It then sends itself a **PaletteChange**  event, and
        notifies all its descendants so they can resolve their palettes as well.

        By default, this property contains the application's default palette.

        **Access functions:**

        QPalette **palette** () const
        void **setPalette** (const QPalette &
        **palette** )

        **See also** **QGuiApplication::palette** (),
        **QGraphicsScene::palette** , and **QPalette::resolve** ().
        """
        ...

    def palette(self) -> QtGui.QPalette:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#palette-prop

        **palette : QPalette**

        This property holds the widget's palette

        This property provides the widget's palette. The palette provides colors
        and brushes for color groups (e.g., **QPalette::Button** ) and states
        (e.g., **QPalette::Inactive** ), loosely defining the general look of
        the widget and its children.

        **QPalette**  consists of color groups that have been explicitly
        defined, and groups that are implicitly inherited from the widget's
        parent. Because of this, palette() can return a different palette than
        what has been set with setPalette(). This scheme allows you to define
        single entries in a palette without affecting the palette's inherited
        entries.

        When a widget's palette changes, it resolves its entries against its
        parent widget, or if it doesn't have a parent widget, it resolves
        against the scene. It then sends itself a **PaletteChange**  event, and
        notifies all its descendants so they can resolve their palettes as well.

        By default, this property contains the application's default palette.

        **Access functions:**

        QPalette **palette** () const
        void **setPalette** (const QPalette &
        **palette** )

        **See also** **QGuiApplication::palette** (),
        **QGraphicsScene::palette** , and **QPalette::resolve** ().
        """
        ...

    def setFont(self, font: QtGui.QFont) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#font-prop

        **font : QFont**

        This property holds the widgets' font

        This property provides the widget's font.

        **QFont**  consists of font properties that have been explicitly defined
        and properties implicitly inherited from the widget's parent. Hence,
        font() can return a different font compared to the one set with
        setFont(). This scheme allows you to define single entries in a font
        without affecting the font's inherited entries.

        When a widget's font changes, it resolves its entries against its parent
        widget. If the widget does not have a parent widget, it resolves its
        entries against the scene. The widget then sends itself a **FontChange**
        event and notifies all its descendants so that they can resolve their
        fonts as well.

        By default, this property contains the application's default font.

        **Access functions:**

        QFont **font** () const
        void **setFont** (const QFont & **font** )

        **See also** **QApplication::font** (), **QGraphicsScene::font** , and
        **QFont::resolve** ().
        """
        ...

    def font(self) -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#font-prop

        **font : QFont**

        This property holds the widgets' font

        This property provides the widget's font.

        **QFont**  consists of font properties that have been explicitly defined
        and properties implicitly inherited from the widget's parent. Hence,
        font() can return a different font compared to the one set with
        setFont(). This scheme allows you to define single entries in a font
        without affecting the font's inherited entries.

        When a widget's font changes, it resolves its entries against its parent
        widget. If the widget does not have a parent widget, it resolves its
        entries against the scene. The widget then sends itself a **FontChange**
        event and notifies all its descendants so that they can resolve their
        fonts as well.

        By default, this property contains the application's default font.

        **Access functions:**

        QFont **font** () const
        void **setFont** (const QFont & **font** )

        **See also** **QApplication::font** (), **QGraphicsScene::font** , and
        **QFont::resolve** ().
        """
        ...

    def setStyle(self, style: QStyle) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#setStyle

        **void QGraphicsWidget::setStyle(QStyle * style )**

        Sets the widget's style to **style**. **QGraphicsWidget**  does **not**
        take ownership of **style**.

        If no style is assigned, or **style** is `nullptr`, the widget will use
        **QGraphicsScene::style** () (if this has been set). Otherwise the
        widget will use **QApplication::style** ().

        This function sets the **Qt::WA_SetStyle**  attribute if **style** is
        not `nullptr`; otherwise it clears the attribute.

        **See also** **style** ().
        """
        ...

    def style(self) -> QStyle:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#style

        **QStyle *QGraphicsWidget::style() const**

        Returns a pointer to the widget's style. If this widget does not have
        any explicitly assigned style, the scene's style is returned instead. In
        turn, if the scene does not have any assigned style, this function
        returns **QApplication::style** ().

        **See also** **setStyle** ().
        """
        ...

    def unsetLayoutDirection(self) -> None:
        ...

    def setLayoutDirection(self, direction: QtCore.Qt.LayoutDirection) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#layoutDirection-prop

        **layoutDirection : Qt::LayoutDirection**

        This property holds the layout direction for this widget.

        This property modifies this widget's and all of its descendants'
        **Qt::WA_RightToLeft**  attribute. It also sets this widget's
        **Qt::WA_SetLayoutDirection**  attribute.

        The widget's layout direction determines the order in which the layout
        manager horizontally arranges subwidgets of this widget. The default
        value depends on the language and locale of the application, and is
        typically in the same direction as words are read and written. With
        **Qt::LeftToRight** , the layout starts placing subwidgets from the left
        side of this widget towards the right. **Qt::RightToLeft**  does the
        opposite - the layout will place widgets starting from the right edge
        moving towards the left.

        Subwidgets inherit their layout direction from the parent. Top-level
        widget items inherit their layout direction from
        QGraphicsScene::layoutDirection. If you change a widget's layout
        direction by calling setLayoutDirection(), the widget will send itself a
        **LayoutDirectionChange**  event, and then propagate the new layout
        direction to all its descendants.

        **Access functions:**

        Qt::LayoutDirection **layoutDirection** () const
        void
        **setLayoutDirection** (Qt::LayoutDirection **direction** )
        void
        **unsetLayoutDirection** ()

        **See also** **QWidget::layoutDirection**  and
        **QApplication::layoutDirection** .
        """
        ...

    def layoutDirection(self) -> QtCore.Qt.LayoutDirection:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#layoutDirection-prop

        **layoutDirection : Qt::LayoutDirection**

        This property holds the layout direction for this widget.

        This property modifies this widget's and all of its descendants'
        **Qt::WA_RightToLeft**  attribute. It also sets this widget's
        **Qt::WA_SetLayoutDirection**  attribute.

        The widget's layout direction determines the order in which the layout
        manager horizontally arranges subwidgets of this widget. The default
        value depends on the language and locale of the application, and is
        typically in the same direction as words are read and written. With
        **Qt::LeftToRight** , the layout starts placing subwidgets from the left
        side of this widget towards the right. **Qt::RightToLeft**  does the
        opposite - the layout will place widgets starting from the right edge
        moving towards the left.

        Subwidgets inherit their layout direction from the parent. Top-level
        widget items inherit their layout direction from
        QGraphicsScene::layoutDirection. If you change a widget's layout
        direction by calling setLayoutDirection(), the widget will send itself a
        **LayoutDirectionChange**  event, and then propagate the new layout
        direction to all its descendants.

        **Access functions:**

        Qt::LayoutDirection **layoutDirection** () const
        void
        **setLayoutDirection** (Qt::LayoutDirection **direction** )
        void
        **unsetLayoutDirection** ()

        **See also** **QWidget::layoutDirection**  and
        **QApplication::layoutDirection** .
        """
        ...

    def adjustSize(self) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#adjustSize

        **void QGraphicsWidget::adjustSize()**

        Adjusts the size of the widget to its effective preferred size hint.

        This function is called implicitly when the item is shown for the first
        time.

        **See also** **effectiveSizeHint** () and **Qt::MinimumSize** .
        """
        ...

    def setLayout(self, layout: QGraphicsLayout) -> None:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#setLayout

        **void QGraphicsWidget::setLayout(QGraphicsLayout * layout )**

        Sets the layout for this widget to **layout**. Any existing layout
        manager is deleted before the new layout is assigned. If **layout** is
        `nullptr`, the widget is left without a layout. Existing subwidgets'
        geometries will remain unaffected.

        All widgets that are currently managed by **layout** or all of its
        sublayouts, are automatically reparented to this item. The layout is
        then invalidated, and the child widget geometries are adjusted according
        to this item's **geometry** () and contentsMargins(). Children who are
        not explicitly managed by **layout** remain unaffected by the layout
        after it has been assigned to this widget.

        **QGraphicsWidget**  takes ownership of **layout**.

        **Note:** Setter function for property **layout** .

        **See also** **layout** (), **QGraphicsLinearLayout::addItem** (), and
        **QGraphicsLayout::invalidate** ().
        """
        ...

    def layout(self) -> QGraphicsLayout:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#layout

        **QGraphicsLayout *QGraphicsWidget::layout() const**

        Returns this widget's layout, or `nullptr` if no layout is currently
        managing this widget.

        **Note:** Getter function for property layout.

        **See also** **setLayout** ().
        """
        ...

    @property
    def geometryChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qgraphicswidget.html#geometryChanged

        **[signal] void QGraphicsWidget::geometryChanged()**

        This signal gets emitted whenever the geometry is changed in
        **setGeometry** ().

        **Note:** Notifier signal for property **geometry** . Notifier signal
        for property **size** .
        """
        ...

    @property
    def layoutChanged(self) -> PyQt6.QtCore.pyqtBoundSignal:
        ...
